/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 56 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 470 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 955 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_DOUBLE;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_*().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1212 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1286 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1307 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1509 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1725 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 276 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 264
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 75
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  int yy20;
  Expr* yy60;
  ExprSpan yy66;
  struct Expr * yy81;
  TriggerStep* yy191;
  With* yy203;
  IdList* yy206;
  enum trim_side_mask yy271;
  ExprList* yy294;
  Select* yy297;
  struct type_def yy302;
  SrcList* yy323;
  struct TrigEvent yy330;
  struct alter_args yy334;
  struct SrcList * yy352;
  bool yy371;
  struct Token yy451;
  struct ExprList * yy475;
  struct LimitVal yy520;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             432
#define YYNRULE              308
#define YY_MAX_SHIFT         431
#define YY_MIN_SHIFTREDUCE   645
#define YY_MAX_SHIFTREDUCE   952
#define YY_MIN_REDUCE        953
#define YY_MAX_REDUCE        1260
#define YY_ERROR_ACTION      1261
#define YY_ACCEPT_ACTION     1262
#define YY_NO_ACTION         1263
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1563)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    66,   67,  287,  307,  827,  827,  837,  840,   64,   64,
 /*    10 */    65,   65,   65,   65,  863,   63,   63,   63,   63,   62,
 /*    20 */    62,   61,   61,   61,   60,  308,   65,   65,   65,   65,
 /*    30 */    58,   63,   63,   63,   63,   62,   62,   61,   61,   61,
 /*    40 */    60,  308,  943,  308,  943,  290,  944,  944,   66,   67,
 /*    50 */   287,  307,  827,  827,  837,  840,   64,   64,   65,   65,
 /*    60 */    65,   65,  128,   63,   63,   63,   63,   62,   62,   61,
 /*    70 */    61,   61,   60,  308, 1262,  431,    2,   66,   67,  287,
 /*    80 */   307,  827,  827,  837,  840,   64,   64,   65,   65,   65,
 /*    90 */    65,  216,   63,   63,   63,   63,   62,   62,   61,   61,
 /*   100 */    61,   60,  308,  945,  746,   53,  911,  912,  913,  914,
 /*   110 */   915,  916,  270,  919,  920,  921,  921,  922, 1214, 1214,
 /*   120 */    43,  867,   50,   51,  889,  889,  425,  113,  113,   52,
 /*   130 */    62,   62,   61,   61,   61,   60,  308,  339,  875,   68,
 /*   140 */   415,    4,   99,   99,  425,  797,  758,  309,  309,  121,
 /*   150 */   185,  185,  345,  345,  763,  764,  310,  387,  310,  281,
 /*   160 */    25,   25,  383,  300,  285,  396,  404,   72,  113,  310,
 /*   170 */   898,  875,  343,  354,  289,  719,  792,  332,  898,  399,
 /*   180 */   397,  192,   65,   65,   65,   65,  383,   63,   63,   63,
 /*   190 */    63,   62,   62,   61,   61,   61,   60,  308,  128,  417,
 /*   200 */   388,   59,   57,  184,  794,   63,   63,   63,   63,   62,
 /*   210 */    62,   61,   61,   61,   60,  308,  268,  417,  796,  796,
 /*   220 */   798,  799,  800,  801,  802,  423,  419,  812,  813,  814,
 /*   230 */   947,   19,   66,   67,  287,  307,  827,  827,  837,  840,
 /*   240 */    64,   64,   65,   65,   65,   65,  362,   63,   63,   63,
 /*   250 */    63,   62,   62,   61,   61,   61,   60,  308,   66,   67,
 /*   260 */   287,  307,  827,  827,  837,  840,   64,   64,   65,   65,
 /*   270 */    65,   65,  667,   63,   63,   63,   63,   62,   62,   61,
 /*   280 */    61,   61,   60,  308,   67,  287,  307,  827,  827,  837,
 /*   290 */   840,   64,   64,   65,   65,   65,   65,  899,   63,   63,
 /*   300 */    63,   63,   62,   62,   61,   61,   61,   60,  308,  413,
 /*   310 */   680,   61,   61,   61,   60,  308,   66,   67,  287,  307,
 /*   320 */   827,  827,  837,  840,   64,   64,   65,   65,   65,   65,
 /*   330 */   250,   63,   63,   63,   63,   62,   62,   61,   61,   61,
 /*   340 */    60,  308,  757,  664,  664,  430,  430,  247,  662,  278,
 /*   350 */   934,  286,  943,  125,  943,  675,  934,   59,   57,  184,
 /*   360 */   677,   66,   67,  287,  307,  827,  827,  837,  840,   64,
 /*   370 */    64,   65,   65,   65,   65,  425,   63,   63,   63,   63,
 /*   380 */    62,   62,   61,   61,   61,   60,  308,  717,  858,  863,
 /*   390 */    71,   25,   25,  373,  674,  372,  211,   59,   57,  184,
 /*   400 */   668,  216,  743,  246,  865,  295,   66,   67,  287,  307,
 /*   410 */   827,  827,  837,  840,   64,   64,   65,   65,   65,   65,
 /*   420 */   296,   63,   63,   63,   63,   62,   62,   61,   61,   61,
 /*   430 */    60,  308,  185,  185,  661,  704,  934,  286,  167,  166,
 /*   440 */   324,  152,  934,  704,  383,  818,  677,  783,  417,  239,
 /*   450 */   113,   66,   67,  287,  307,  827,  827,  837,  840,   64,
 /*   460 */    64,   65,   65,   65,   65,  730,   63,   63,   63,   63,
 /*   470 */    62,   62,   61,   61,   61,   60,  308,  313,  901,  315,
 /*   480 */   688,  689,  690,   59,   57,  184,  828,  828,  838,  841,
 /*   490 */   791,  318,  129,  351,  252,  251,   66,   67,  287,  307,
 /*   500 */   827,  827,  837,  840,   64,   64,   65,   65,   65,   65,
 /*   510 */   670,   63,   63,   63,   63,   62,   62,   61,   61,   61,
 /*   520 */    60,  308,   66,   67,  287,  307,  827,  827,  837,  840,
 /*   530 */    64,   64,   65,   65,   65,   65,  352,   63,   63,   63,
 /*   540 */    63,   62,   62,   61,   61,   61,   60,  308,   66,   67,
 /*   550 */   287,  307,  827,  827,  837,  840,   64,   64,   65,   65,
 /*   560 */    65,   65,  663,   63,   63,   63,   63,   62,   62,   61,
 /*   570 */    61,   61,   60,  308,   66,   67,  287,  307,  827,  827,
 /*   580 */   837,  840,   64,   64,   65,   65,   65,   65,  322,   63,
 /*   590 */    63,   63,   63,   62,   62,   61,   61,   61,   60,  308,
 /*   600 */    53,  222,  944,  944,  165,  164,  321,  669,  761,  762,
 /*   610 */   872,   29,  871,  786,  314,    6,  320,   50,   51,  943,
 /*   620 */   337,  943,  887,   70,   52,  113,   45,  797,  686,  231,
 /*   630 */   334,  385,  743,  797,  113,  415,    4, 1160,  128,  425,
 /*   640 */   797,  863,  309,  309,  663,  223,  380,  743,  808,  170,
 /*   650 */   182,  149,   48,  252,  251,   25,   25,  727,  792,  945,
 /*   660 */   745,  404,  726,  243,  792,  122,   60,  308,  216,  297,
 /*   670 */   775,  792,  306,  287,  307,  827,  827,  837,  840,   64,
 /*   680 */    64,   65,   65,   65,   65,  230,   63,   63,   63,   63,
 /*   690 */    62,   62,   61,   61,   61,   60,  308,  646,  312,  794,
 /*   700 */   796,  796,  798,  799,  800,  801,  796,  796,  798,  799,
 /*   710 */   800,  801,  417,  796,  796,  798,  799,  800,  801,  802,
 /*   720 */   423,  419,  223,  380,  760,  947,   19,   66,   67,  287,
 /*   730 */   307,  827,  827,  837,  840,   64,   64,   65,   65,   65,
 /*   740 */    65,  743,   63,   63,   63,   63,   62,   62,   61,   61,
 /*   750 */    61,   60,  308,   66,   56,  287,  307,  827,  827,  837,
 /*   760 */   840,   64,   64,   65,   65,   65,   65,   53,   63,   63,
 /*   770 */    63,   63,   62,   62,   61,   61,   61,   60,  308,  197,
 /*   780 */   128,  664,  664,  790,   50,   51,   59,   57,  184,  700,
 /*   790 */   180,   52,  303,  429,  744,  650,  428,  226,  279,   53,
 /*   800 */   687,  656,  415,    4,  786,  128,  128,  797,  224,  309,
 /*   810 */   309,  694,  368,  366,  372,  299,   50,   51,  731,  370,
 /*   820 */   242,  344,  701,   52,  695,  737,  365,  422,  404,  987,
 /*   830 */   146,  744,  425,  987,  415,    4,  664,  664,  792,  797,
 /*   840 */   215,  309,  309,  676,  301,  252,  251,  338,   82,   82,
 /*   850 */   390,  329,  173,  744,  243,  284,  172,  425,  147,  128,
 /*   860 */   404,  224,  162,  257,  664,  664,  794,  402,  680,  379,
 /*   870 */   792,  722,  722,   79,   79,  342,  250,  330,  425,  759,
 /*   880 */   796,  796,  798,  799,  800,  801,  802,  423,  419,  173,
 /*   890 */   744,  331,  947,   19,   99,   99,  377,  259,  794,  113,
 /*   900 */   194,  418,   54,   18,  375,  417,  425,  325,  175,  422,
 /*   910 */   378,  732,  796,  796,  798,  799,  800,  801,  802,  423,
 /*   920 */   419,   53,   99,   99,  947,   19,  709,  709,  892,  349,
 /*   930 */   417,  399,  381,  425,  664,  664,  425,  790,   50,   51,
 /*   940 */   743,   59,   57,  184,  893,   52,  347,  236,  795,   99,
 /*   950 */    99,  417,   99,   99,  894,  710,  415,    4,  743,  399,
 /*   960 */   386,  797,  711,  309,  309,  121,   73,  707,  707,  743,
 /*   970 */   358,  355,  664,  664,  932,  282,  727,  425,  198,  417,
 /*   980 */   285,  726,  404,  268,  128,  932,  399,  395,  347,  399,
 /*   990 */   416,  743,  792,   99,   99,  892,  895,  425,    1,  869,
 /*  1000 */   425,  292,  425,  235,  664,  664,  417,  864,  786,  417,
 /*  1010 */   171,  893,  196,   27,   27,  353,   99,   99,   99,   99,
 /*  1020 */   794,  894,  403,  261,  242,  344,  298,  664,  664,  713,
 /*  1030 */   399,  376,  183,  182,  796,  796,  798,  799,  800,  801,
 /*  1040 */   802,  423,  419,  177,  425,  234,  947,   19,  425,  233,
 /*  1050 */   417,  425,  263,  304,  202,  391,  743,  743,  243,  266,
 /*  1060 */    25,   25,  384,  353,   97,   97,  425,   97,   97,  425,
 /*  1070 */   417,  425,  790,  417,  393,  417,  409,  790,   24,   24,
 /*  1080 */   425,  942,   75,   75,  425,   84,   84,   85,   85,  425,
 /*  1090 */   154,  425,  353,  425,  712,  238,   86,   86,  425,  790,
 /*  1100 */    87,   87,   49,  201,   47,   88,   88,   28,   28,   76,
 /*  1110 */    76,  425,   40,  425,   78,   78,  229,  417,  763,  764,
 /*  1120 */   398,  417,  716,  267,  417,  113,  424,   89,   89,   90,
 /*  1130 */    90,  425,    9,  425,  406,  417,  293,  113,  160,  417,
 /*  1140 */   905,  294,  417,  425,  417,  678,  678,   91,   91,   26,
 /*  1150 */    26,  241,  425,  417,  168,  169,  186,  417,  425,   92,
 /*  1160 */    92,  425,  417,  305,  417,  425,  417,  410,   93,   93,
 /*  1170 */   113,  417,  693,  692,   94,   94,  425,   80,   80,  900,
 /*  1180 */   204,   95,   95,   42,  417,  425,  417,  414,  803,  803,
 /*  1190 */   113,  903,   96,   96,  425,  316,  788,  831,  425,  218,
 /*  1200 */   214,   81,   81,  425,  417,  425,  417,  425,  897,  346,
 /*  1210 */   118,  118,  425,  214,  119,  119,  417,  972,  904,  120,
 /*  1220 */   120,  103,  103,   98,   98,  417,  425,  326,   83,   83,
 /*  1230 */   425,  417,  348,  291,  417,  425,  214,  425,  417,  425,
 /*  1240 */   857,  363,  106,  106,   42,  218,  100,  100,  425,  417,
 /*  1250 */   327,  107,  107,  105,  105,  117,  117,  425,  417,  703,
 /*  1260 */   328,  778,  333,   42,  112,  112,  425,  417,  702,  232,
 /*  1270 */   335,  417,   36,  111,  111,  425,  417,  425,  417,  425,
 /*  1280 */   417,  425,  110,  110,  176,  417,  724,  886,  425,  256,
 /*  1290 */    44,  108,  108,  109,  109,  102,  102,  104,  104,  417,
 /*  1300 */   240,  425,  255,  417,  101,  101,  350,  425,  417,  753,
 /*  1310 */   417,  861,  417,  214,  884,  218,  929,   74,   74,  673,
 /*  1320 */    23,  417,  883,   77,   77,  356,  357,  245,  655,  249,
 /*  1330 */   417,  254,  265,  751,  789,  733,  862,  405,  269,  417,
 /*  1340 */     8,  275,  161,  665,  653,  652,  654,  288,  417,  153,
 /*  1350 */   417,  228,  417,  144,  417,  133,  123,  135,   40,  114,
 /*  1360 */   774,  417,  336,   31,  870,  341,  361,  237,  200,  369,
 /*  1370 */   359,  888,  155,  207,  417,  208,  137,  199,  139,  140,
 /*  1380 */   417,  148,  785,  209,  698,  302,  683,  115,  371,  248,
 /*  1390 */   389,  253,  684,  116,  672,  374,   39,  671,    7,  217,
 /*  1400 */   697,  408,   46,  421,  412,  918,   69,  394,   41,  392,
 /*  1410 */   427,  723,  741,  258,  930,  742,  740,  276,  260,  262,
 /*  1420 */   283,  739,   10,  273,  271,  277,  926,  225,  845,  227,
 /*  1430 */   272,  274,   20,   21,  264,  928,  648,  311,   11,  902,
 /*  1440 */    30,  187,  130,  317,  188,  189,  319,  190,  323,  131,
 /*  1450 */   191,  163,  868,  195,  193,  132,  126,  134,  784,  138,
 /*  1460 */   714,  873,  136,  214,  340,  141,  142,  882,  143,  949,
 /*  1470 */   145,   32,   33,   34,   35,  127,  885,  203,  881,   12,
 /*  1480 */   205,   22,  206,  244,  156,  658,  360,  255,  210,  150,
 /*  1490 */   364,   13,   14,  367,  168,   37,  696,  212,  169,  124,
 /*  1500 */   817,   38,  721,  382,  178,  815,  843,   15,  747,  725,
 /*  1510 */     5,  213,  179,  181,  151,  407,  856,  420,  844,  174,
 /*  1520 */   752,   44,   16,   42,  842,   17,  809,  891,  400,  890,
 /*  1530 */   401,  909,  157,  158,  219,  910,  411,  846,  847,  159,
 /*  1540 */   426,  816,  220,  221,  805,    3,  280,  917,  804,   55,
 /*  1550 */   649,  645,  659, 1231,  955,  955,  955,  955,  955,  955,
 /*  1560 */   955,  955,  832,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*    10 */    15,   16,   17,   18,  167,   20,   21,   22,   23,   24,
 /*    20 */    25,   26,   27,   28,   29,   30,   15,   16,   17,   18,
 /*    30 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*    40 */    29,   30,   47,   30,   49,  198,   49,   50,    5,    6,
 /*    50 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    60 */    17,   18,   45,   20,   21,   22,   23,   24,   25,   26,
 /*    70 */    27,   28,   29,   30,  161,  162,  163,    5,    6,    7,
 /*    80 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*    90 */    18,   96,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   100 */    28,   29,   30,  106,  107,    7,  148,  149,  150,  151,
 /*   110 */   152,  153,  154,  155,  156,  157,  158,  159,  101,  102,
 /*   120 */    48,   44,   24,   25,  206,  206,  167,  209,  209,   31,
 /*   130 */    24,   25,   26,   27,   28,   29,   30,   85,   86,   67,
 /*   140 */    42,   43,  183,  184,  167,   47,  186,   49,   50,  167,
 /*   150 */   207,  208,  234,  234,  111,  112,  174,    7,  176,  177,
 /*   160 */   183,  184,  219,   84,  182,  206,   68,  249,  209,  187,
 /*   170 */   191,  119,  254,  254,  197,  208,   78,  234,  199,  220,
 /*   180 */   221,  104,   15,   16,   17,   18,  219,   20,   21,   22,
 /*   190 */    23,   24,   25,   26,   27,   28,   29,   30,   45,  240,
 /*   200 */    50,  241,  242,  243,  106,   20,   21,   22,   23,   24,
 /*   210 */    25,   26,   27,   28,   29,   30,  167,  240,  120,  121,
 /*   220 */   122,  123,  124,  125,  126,  127,  128,  129,  130,  131,
 /*   230 */   132,  133,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   240 */    13,   14,   15,   16,   17,   18,    7,   20,   21,   22,
 /*   250 */    23,   24,   25,   26,   27,   28,   29,   30,    5,    6,
 /*   260 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   270 */    17,   18,  183,   20,   21,   22,   23,   24,   25,   26,
 /*   280 */    27,   28,   29,   30,    6,    7,    8,    9,   10,   11,
 /*   290 */    12,   13,   14,   15,   16,   17,   18,   44,   20,   21,
 /*   300 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  260,
 /*   310 */    83,   26,   27,   28,   29,   30,    5,    6,    7,    8,
 /*   320 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   330 */    91,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   340 */    29,   30,  186,   49,   50,  164,  165,   39,  179,  168,
 /*   350 */   181,  182,   47,  172,   49,   44,  187,  241,  242,  243,
 /*   360 */   191,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   370 */    14,   15,   16,   17,   18,  167,   20,   21,   22,   23,
 /*   380 */    24,   25,   26,   27,   28,   29,   30,  206,   80,  167,
 /*   390 */   209,  183,  184,   79,   80,   81,   82,  241,  242,  243,
 /*   400 */    44,   96,  167,   95,  183,  197,    5,    6,    7,    8,
 /*   410 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   420 */   198,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   430 */    29,   30,  207,  208,  179,  191,  181,  182,  257,  258,
 /*   440 */   205,  147,  187,  199,  219,   44,  191,  206,  240,  141,
 /*   450 */   209,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   460 */    14,   15,   16,   17,   18,  223,   20,   21,   22,   23,
 /*   470 */    24,   25,   26,   27,   28,   29,   30,   79,   80,   81,
 /*   480 */    87,   88,   89,  241,  242,  243,    9,   10,   11,   12,
 /*   490 */    44,   93,  190,    7,  192,  193,    5,    6,    7,    8,
 /*   500 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   510 */   183,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   520 */    29,   30,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   530 */    13,   14,   15,   16,   17,   18,   50,   20,   21,   22,
 /*   540 */    23,   24,   25,   26,   27,   28,   29,   30,    5,    6,
 /*   550 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   560 */    17,   18,  180,   20,   21,   22,   23,   24,   25,   26,
 /*   570 */    27,   28,   29,   30,    5,    6,    7,    8,    9,   10,
 /*   580 */    11,   12,   13,   14,   15,   16,   17,   18,   53,   20,
 /*   590 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   600 */     7,  212,   49,   50,   24,   25,   71,  183,   73,   74,
 /*   610 */    54,  222,   56,   69,  259,   43,  232,   24,   25,   47,
 /*   620 */    64,   49,  206,   43,   31,  209,  135,   47,  194,   85,
 /*   630 */    86,  206,  167,   47,  209,   42,   43,   44,   45,  167,
 /*   640 */    47,  167,   49,   50,  262,  101,  102,  167,  105,  224,
 /*   650 */   225,  190,  135,  192,  193,  183,  184,   98,   78,  106,
 /*   660 */   107,   68,  103,  119,   78,   96,   29,   30,   96,  197,
 /*   670 */   205,   78,  198,    7,    8,    9,   10,   11,   12,   13,
 /*   680 */    14,   15,   16,   17,   18,  205,   20,   21,   22,   23,
 /*   690 */    24,   25,   26,   27,   28,   29,   30,    1,    2,  106,
 /*   700 */   120,  121,  122,  123,  124,  125,  120,  121,  122,  123,
 /*   710 */   124,  125,  240,  120,  121,  122,  123,  124,  125,  126,
 /*   720 */   127,  128,  101,  102,  179,  132,  133,    5,    6,    7,
 /*   730 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   740 */    18,  167,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   750 */    28,   29,   30,    5,    6,    7,    8,    9,   10,   11,
 /*   760 */    12,   13,   14,   15,   16,   17,   18,    7,   20,   21,
 /*   770 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  205,
 /*   780 */    45,   49,   50,  167,   24,   25,  241,  242,  243,   59,
 /*   790 */    44,   31,    7,   32,   48,   34,   35,   36,   37,    7,
 /*   800 */   194,   40,   42,   43,   69,   45,   45,   47,   76,   49,
 /*   810 */    50,   57,   79,   80,   81,   30,   24,   25,   26,   65,
 /*   820 */    85,   86,   92,   31,   70,  226,   93,  180,   68,   44,
 /*   830 */    43,   48,  167,   48,   42,   43,   49,   50,   78,   47,
 /*   840 */   223,   49,   50,  190,   90,  192,  193,  231,  183,  184,
 /*   850 */   230,   90,  106,  107,  119,   94,  230,  167,   43,   45,
 /*   860 */    68,   76,   77,   78,   49,   50,  106,  203,   83,   97,
 /*   870 */    78,   99,  100,  183,  184,  251,   91,  116,  167,  179,
 /*   880 */   120,  121,  122,  123,  124,  125,  126,  127,  128,  106,
 /*   890 */   107,   77,  132,  133,  183,  184,  206,  223,  106,  209,
 /*   900 */   139,  236,  237,  238,   26,  240,  167,  146,  250,  262,
 /*   910 */   220,   26,  120,  121,  122,  123,  124,  125,  126,  127,
 /*   920 */   128,    7,  183,  184,  132,  133,  202,  203,   35,  167,
 /*   930 */   240,  220,  221,  167,   49,   50,  167,  167,   24,   25,
 /*   940 */   167,  241,  242,  243,   51,   31,  167,   39,  167,  183,
 /*   950 */   184,  240,  183,  184,   61,   62,   42,   43,  167,  220,
 /*   960 */   221,   47,   69,   49,   50,  167,   43,  202,  203,  167,
 /*   970 */   247,  248,   49,   50,  176,  177,   98,  167,  205,  240,
 /*   980 */   182,  103,   68,  167,   45,  187,  220,  221,  167,  220,
 /*   990 */   221,  167,   78,  183,  184,   35,  205,  167,   43,   60,
 /*  1000 */   167,  231,  167,   95,   49,   50,  240,  205,   69,  240,
 /*  1010 */   167,   51,  233,  183,  184,  167,  183,  184,  183,  184,
 /*  1020 */   106,   61,   62,  223,   85,   86,  196,   49,   50,  205,
 /*  1030 */   220,  221,  224,  225,  120,  121,  122,  123,  124,  125,
 /*  1040 */   126,  127,  128,   48,  167,  137,  132,  133,  167,  141,
 /*  1050 */   240,  167,  223,  220,  233,  220,  167,  167,  119,  167,
 /*  1060 */   183,  184,  167,  167,  183,  184,  167,  183,  184,  167,
 /*  1070 */   240,  167,  167,  240,  197,  240,  260,  167,  183,  184,
 /*  1080 */   167,   48,  183,  184,  167,  183,  184,  183,  184,  167,
 /*  1090 */   210,  167,  167,  167,  205,  205,  183,  184,  167,  167,
 /*  1100 */   183,  184,  134,  255,  136,  183,  184,  183,  184,  183,
 /*  1110 */   184,  167,  117,  167,  183,  184,  167,  240,  111,  112,
 /*  1120 */   239,  240,  206,  239,  240,  209,    7,  183,  184,  183,
 /*  1130 */   184,  167,  211,  167,  206,  240,  231,  209,  105,  240,
 /*  1140 */   167,  231,  240,  167,  240,   49,   50,  183,  184,  183,
 /*  1150 */   184,  255,  167,  240,   85,   86,   43,  240,  167,  183,
 /*  1160 */   184,  167,  240,  231,  240,  167,  240,  206,  183,  184,
 /*  1170 */   209,  240,   77,   78,  183,  184,  167,  183,  184,   44,
 /*  1180 */   255,  183,  184,   48,  240,  167,  240,  206,   49,   50,
 /*  1190 */   209,  167,  183,  184,  167,   44,   44,   78,  167,   48,
 /*  1200 */    48,  183,  184,  167,  240,  167,  240,  167,  167,   44,
 /*  1210 */   183,  184,  167,   48,  183,  184,  240,  104,  167,  183,
 /*  1220 */   184,  183,  184,  183,  184,  240,  167,  167,  183,  184,
 /*  1230 */   167,  240,   44,  167,  240,  167,   48,  167,  240,  167,
 /*  1240 */    44,   44,  183,  184,   48,   48,  183,  184,  167,  240,
 /*  1250 */   167,  183,  184,  183,  184,  183,  184,  167,  240,   44,
 /*  1260 */   167,  214,  227,   48,  183,  184,  167,  240,   44,  227,
 /*  1270 */   167,  240,   48,  183,  184,  167,  240,  167,  240,  167,
 /*  1280 */   240,  167,  183,  184,  167,  240,   44,  214,  167,   78,
 /*  1290 */    48,  183,  184,  183,  184,  183,  184,  183,  184,  240,
 /*  1300 */   256,  167,   91,  240,  183,  184,  256,  167,  240,   44,
 /*  1310 */   240,   44,  240,   48,  167,   48,   44,  183,  184,  186,
 /*  1320 */    48,  240,  167,  183,  184,  167,  167,  167,  167,  167,
 /*  1330 */   240,  167,  227,  167,  167,  167,  167,  246,  167,  240,
 /*  1340 */   211,  213,  211,  167,  167,  167,  167,    9,  240,   43,
 /*  1350 */   240,  188,  240,   43,  240,  235,    5,  201,  117,  189,
 /*  1360 */   214,  240,   41,  134,  253,  143,   41,  252,  173,   84,
 /*  1370 */   188,  214,  235,  173,  240,  173,  204,  204,  204,  204,
 /*  1380 */   240,  201,  201,  173,  195,   63,  192,  189,   84,  188,
 /*  1390 */   109,  188,  193,  189,  185,   84,   84,  185,   43,  245,
 /*  1400 */   195,  188,  134,   43,  188,  261,  115,  110,  114,  113,
 /*  1410 */    46,  218,  229,  228,  175,  229,  229,   45,  228,  228,
 /*  1420 */   170,  229,   43,  215,  217,  169,   36,  166,  244,  166,
 /*  1430 */   216,  214,  178,  178,  228,  171,    4,    3,   43,   66,
 /*  1440 */    43,   82,   43,   66,   76,   38,   81,   76,   94,   39,
 /*  1450 */    76,   14,   44,  138,   43,   39,   90,  118,  102,   84,
 /*  1460 */    42,  142,  105,   48,  144,  142,   84,    1,  105,  145,
 /*  1470 */   118,   14,   14,   14,   14,   90,   50,  108,    1,   43,
 /*  1480 */   104,  140,   84,  137,   96,   42,    7,   91,   82,   43,
 /*  1490 */    66,   43,   43,   66,   85,   43,   52,   66,   86,   58,
 /*  1500 */    44,   48,   98,   48,  104,   44,   44,   43,  107,   44,
 /*  1510 */    43,  108,   44,   44,   43,   96,   44,  125,   44,   43,
 /*  1520 */    50,   48,  108,   48,   44,  108,  105,   44,   47,   44,
 /*  1530 */    48,   44,   43,   43,   48,   44,   96,   44,   60,   43,
 /*  1540 */    14,   44,   43,  104,   44,   43,   38,   44,   44,   43,
 /*  1550 */    33,    1,   47,    0,  263,  263,  263,  263,  263,  263,
 /*  1560 */   263,  263,   78,
};
#define YY_SHIFT_USE_DFLT (1563)
#define YY_SHIFT_COUNT    (431)
#define YY_SHIFT_MIN      (-42)
#define YY_SHIFT_MAX      (1553)
static const short yy_shift_ofst[] = {
 /*     0 */   696,  593,  761,   98,  760,  914,  914,  914,  914,  914,
 /*    10 */   732,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    20 */   785,  785,  735,  732,   -5,   43,   43,  227,  227,  792,
 /*    30 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    40 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    50 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    60 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    70 */   914,  544,  939,   17,   72,  253,  311,  356,  401,  446,
 /*    80 */   491,  517,  543,  569,  722,  722,  722,  722,  722,  722,
 /*    90 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   100 */   748,  722,  278,  666,  666,   11,  167,  167,  167,  185,
 /*   110 */   106,  285,  637,  621,   79,   79,   79,   13, 1563, 1563,
 /*   120 */  1563,  -42,  -42,  893,  893,  308,  787,  787,  294,  239,
 /*   130 */   978,  978,  978,  814,  978,  978,  978,  978,  978,  978,
 /*   140 */   978,  978,  978,  978,  978,  978,  978,  978,  978,  239,
 /*   150 */   978,  978,  978,  978,  621,  153,  153,  153,  153,  153,
 /*   160 */  1563, 1563,  580,  586,  586,  586,  398,  535,  754,  754,
 /*   170 */   746,  572,   -3,  553,  960,   52,  556,  815,  885,  305,
 /*   180 */   305,  305,  923,  783,  955,  772,  878,  978,  978,  978,
 /*   190 */   978,  978,  978,  978,  978,  978,  995,  150,  150,  978,
 /*   200 */   978,  486,  995,  978,  486,  978,  978,  978,  978,  978,
 /*   210 */   978,  978, 1007,  978,  978,  150,  978,  968,  978,  978,
 /*   220 */   559,  978, 1033,  559,  978,  978,  978,  978, 1338, 1306,
 /*   230 */  1310, 1351, 1241, 1321, 1321, 1321, 1321, 1229, 1222, 1325,
 /*   240 */  1241, 1310, 1351, 1351, 1325, 1306, 1325, 1325, 1338, 1306,
 /*   250 */  1322, 1285, 1304, 1338, 1306, 1322, 1311, 1311, 1281, 1312,
 /*   260 */  1281, 1312, 1281, 1312, 1281, 1312, 1355, 1268, 1306, 1306,
 /*   270 */  1360, 1291, 1297, 1294, 1296, 1241, 1364, 1372, 1379, 1390,
 /*   280 */  1390, 1563, 1563, 1563,  908,  733,  314,  477,  393, 1135,
 /*   290 */  1151,   77, 1152, 1165, 1188, 1196, 1197, 1215, 1224, 1096,
 /*   300 */  1069, 1095,  730, 1211, 1242, 1265, 1267, 1119, 1139, 1113,
 /*   310 */  1272, 1432, 1434, 1373, 1395, 1397, 1359, 1399, 1377, 1368,
 /*   320 */  1365, 1407, 1371, 1374, 1354, 1410, 1408, 1411, 1437, 1315,
 /*   330 */  1416, 1356, 1339, 1366, 1357, 1375, 1418, 1319, 1415, 1323,
 /*   340 */  1324, 1320, 1382, 1466, 1363, 1352, 1457, 1458, 1459, 1460,
 /*   350 */  1385, 1426, 1369, 1376, 1477, 1341, 1436, 1398, 1346, 1388,
 /*   360 */  1443, 1479, 1396, 1406, 1446, 1424, 1448, 1449, 1427, 1409,
 /*   370 */  1444, 1412, 1452, 1431, 1441, 1456, 1461, 1462, 1453, 1404,
 /*   380 */  1464, 1465, 1467, 1455, 1400, 1468, 1469, 1470, 1403, 1471,
 /*   390 */  1401, 1473, 1414, 1475, 1417, 1472, 1474, 1480, 1421, 1473,
 /*   400 */  1483, 1481, 1482, 1485, 1476, 1478, 1487, 1489, 1419, 1486,
 /*   410 */  1491, 1490, 1440, 1486, 1493, 1496, 1497, 1499, 1500, 1502,
 /*   420 */  1503, 1392, 1504, 1506, 1484, 1439, 1505, 1526, 1508, 1517,
 /*   430 */  1550, 1553,
};
#define YY_REDUCE_USE_DFLT (-154)
#define YY_REDUCE_COUNT (283)
#define YY_REDUCE_MIN   (-153)
#define YY_REDUCE_MAX   (1264)
static const short yy_reduce_ofst[] = {
 /*     0 */   -87,  -41,  181,  665,  690,  711,  739,  766,  769,  810,
 /*    10 */   -18,  -23,  208,  472,  830,  833,  835,  877,  881,  884,
 /*    20 */   169,  255,  -82,  798,  242,  -40,  156,  545,  700,  895,
 /*    30 */   899,  902,  904,  913,  917,  922,  924,  926,  931,  944,
 /*    40 */   946,  964,  966,  976,  985,  991,  994,  998, 1009, 1018,
 /*    50 */  1027, 1031, 1036, 1038, 1040, 1045, 1059, 1063, 1068, 1070,
 /*    60 */  1072, 1081, 1090, 1099, 1108, 1110, 1112, 1114, 1121, 1134,
 /*    70 */  1140,  -57,  -81,  425,  116,  116,  116,  116,  116,  116,
 /*    80 */   116,  116,  116,  116,  116,  116,  116,  116,  116,  116,
 /*    90 */   116,  116,  116,  116,  116,  116,  116,  116,  116,  116,
 /*   100 */   116,  116,  116,  116,  116,  116,  116,  116,  116,  116,
 /*   110 */   116,  116,  116,  225,  302,  461,  653,  116,  116,  116,
 /*   120 */   116,  382,  647,  724,  765,  723,  779,  821,   49,  -21,
 /*   130 */  -153,  235,  465,  241,  480,  574,  773,  791,  802,  824,
 /*   140 */   889,  616,  890,  848,  770,  896,  905,  910,  925,  244,
 /*   150 */   222,  932,  816,  474,  -33,  416,  916,  928,  961,  981,
 /*   160 */   808,  389,   89,  221,  327,  424,  355,  384,  434,  606,
 /*   170 */   599,  617,  620,  626,  664,  624,  658,  762,  781,  674,
 /*   180 */   800,  829,  843,  599,  892,  880,  921,  949,  973, 1024,
 /*   190 */  1041, 1051, 1060, 1066, 1083, 1093, 1047, 1035, 1042, 1103,
 /*   200 */  1117, 1044, 1073, 1147, 1050, 1155, 1158, 1159, 1160, 1161,
 /*   210 */  1162, 1164, 1133, 1166, 1167, 1105, 1168, 1091, 1169, 1171,
 /*   220 */  1129,  781, 1128, 1131, 1176, 1177, 1178, 1179, 1170, 1163,
 /*   230 */  1120, 1156, 1146, 1172, 1173, 1174, 1175, 1111, 1115, 1195,
 /*   240 */  1157, 1137, 1180, 1181, 1200, 1182, 1202, 1210, 1198, 1201,
 /*   250 */  1189, 1194, 1199, 1204, 1203, 1205, 1209, 1212, 1183, 1185,
 /*   260 */  1186, 1190, 1187, 1191, 1192, 1206, 1184, 1154, 1213, 1216,
 /*   270 */  1144, 1193, 1207, 1214, 1208, 1217, 1239, 1250, 1256, 1261,
 /*   280 */  1263, 1254, 1255, 1264,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1232, 1214, 1214, 1261, 1214, 1160, 1160, 1160, 1160, 1160,
 /*    10 */   974, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1118, 1118,
 /*    20 */   974,  974, 1214,  974, 1042, 1073, 1073,  987,  987, 1261,
 /*    30 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*    40 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*    50 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*    60 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*    70 */  1261, 1261, 1214, 1046, 1079, 1261, 1261, 1261, 1161, 1162,
 /*    80 */  1261, 1261, 1115, 1261, 1188, 1090, 1089, 1088, 1087, 1056,
 /*    90 */  1085, 1077, 1081, 1161, 1157, 1158, 1156, 1119, 1114, 1162,
 /*   100 */  1261, 1080, 1128, 1141, 1127, 1137, 1147, 1138, 1130, 1129,
 /*   110 */  1131, 1132, 1133, 1261,  993,  993,  993, 1134, 1144, 1143,
 /*   120 */  1142, 1261, 1261, 1261, 1261, 1167, 1261, 1261, 1261, 1013,
 /*   130 */  1261, 1261, 1261, 1214, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   140 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1013,
 /*   150 */  1261, 1261, 1261, 1261, 1261, 1214, 1214, 1214, 1214, 1214,
 /*   160 */  1046, 1037, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   170 */  1261, 1042, 1261, 1261, 1261, 1261, 1182, 1261, 1261, 1042,
 /*   180 */  1042, 1042, 1261, 1044, 1261, 1026, 1036, 1261, 1261, 1261,
 /*   190 */  1261, 1261, 1261, 1261, 1261, 1261, 1084, 1058, 1058, 1261,
 /*   200 */  1261, 1259, 1084, 1261, 1259, 1261, 1261, 1261, 1261, 1261,
 /*   210 */  1261, 1261, 1073, 1261, 1261, 1058, 1261, 1159, 1261, 1261,
 /*   220 */  1036, 1261, 1043, 1036, 1261, 1261, 1261, 1261,  999, 1168,
 /*   230 */  1095, 1016, 1084, 1023, 1023, 1023, 1023, 1187, 1186,  965,
 /*   240 */  1084, 1095, 1016, 1016,  965, 1168,  965,  965,  999, 1168,
 /*   250 */  1007,  990,  989,  999, 1168, 1007, 1014, 1014, 1062, 1057,
 /*   260 */  1062, 1057, 1062, 1057, 1062, 1057, 1163, 1261, 1168, 1168,
 /*   270 */  1261, 1078, 1063, 1076, 1074, 1084, 1261, 1239, 1261, 1235,
 /*   280 */  1235, 1243, 1243,  968, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   290 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   300 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1101,
 /*   310 */  1261, 1261,  955, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   320 */  1261, 1261, 1261, 1261, 1204, 1261, 1261, 1174, 1261, 1261,
 /*   330 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1185, 1184,
 /*   340 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   350 */  1261, 1261, 1261, 1258, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   360 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   370 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1028,
 /*   380 */  1261, 1261, 1261, 1249, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   390 */  1261, 1075, 1261, 1064, 1261, 1261, 1261, 1261, 1261, 1256,
 /*   400 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261, 1216,
 /*   410 */  1261, 1261, 1261, 1215, 1261, 1261, 1261, 1261, 1261, 1261,
 /*   420 */  1261, 1261, 1261, 1261, 1261, 1261, 1261, 1261,  959, 1261,
 /*   430 */  1261, 1261,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   49,  /*      QUERY => ID */
   49,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   49,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   49,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   49,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*       WITH => nothing */
   49,  /*     ENGINE => ID */
    0,  /*     STRING => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   49,  /*      ABORT => ID */
   49,  /*     ACTION => ID */
   49,  /*        ADD => ID */
   49,  /*      AFTER => ID */
   49,  /* AUTOINCREMENT => ID */
   49,  /*     BEFORE => ID */
   49,  /*    CASCADE => ID */
   49,  /*   CONFLICT => ID */
   49,  /*   DEFERRED => ID */
   49,  /*        END => ID */
   49,  /*       FAIL => ID */
   49,  /*     IGNORE => ID */
   49,  /*  INITIALLY => ID */
   49,  /*    INSTEAD => ID */
   49,  /*         NO => ID */
   49,  /*        KEY => ID */
   49,  /*     OFFSET => ID */
   49,  /*      RAISE => ID */
   49,  /*    REPLACE => ID */
   49,  /*   RESTRICT => ID */
   49,  /*     RENAME => ID */
   49,  /*   CTIME_KW => ID */
   49,  /*     ENABLE => ID */
   49,  /*    DISABLE => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "WITH",          "ENGINE",        "STRING",      
  "COMMA",         "ID",            "INDEXED",       "ABORT",       
  "ACTION",        "ADD",           "AFTER",         "AUTOINCREMENT",
  "BEFORE",        "CASCADE",       "CONFLICT",      "DEFERRED",    
  "END",           "FAIL",          "IGNORE",        "INITIALLY",   
  "INSTEAD",       "NO",            "KEY",           "OFFSET",      
  "RAISE",         "REPLACE",       "RESTRICT",      "RENAME",      
  "CTIME_KW",      "ENABLE",        "DISABLE",       "ANY",         
  "CONSTRAINT",    "DEFAULT",       "NULL",          "PRIMARY",     
  "UNIQUE",        "CHECK",         "REFERENCES",    "AUTOINCR",    
  "ON",            "UPDATE",        "DELETE",        "SIMPLE",      
  "PARTIAL",       "FULL",          "SET",           "DEFERRABLE",  
  "IMMEDIATE",     "FOREIGN",       "DROP",          "VIEW",        
  "AS",            "UNION",         "ALL",           "EXCEPT",      
  "INTERSECT",     "SELECT",        "VALUES",        "DISTINCT",    
  "DOT",           "FROM",          "JOIN_KW",       "JOIN",        
  "BY",            "USING",         "ORDER",         "ASC",         
  "DESC",          "GROUP",         "HAVING",        "LIMIT",       
  "TRUNCATE",      "WHERE",         "INTO",          "INSERT",      
  "FLOAT",         "BLOB",          "FALSE",         "TRUE",        
  "UNKNOWN",       "INTEGER",       "VARIABLE",      "CAST",        
  "TRIM",          "LEADING",       "TRAILING",      "BOTH",        
  "CHAR",          "CASE",          "WHEN",          "THEN",        
  "ELSE",          "INDEX",         "SESSION",       "PRAGMA",      
  "BEGIN",         "TRIGGER",       "OF",            "FOR",         
  "EACH",          "ROW",           "ALTER",         "RECURSIVE",   
  "TEXT",          "STRING_KW",     "SCALAR",        "BOOL",        
  "BOOLEAN",       "VARBINARY",     "VARCHAR",       "NUMBER",      
  "DOUBLE",        "INT",           "INTEGER_KW",    "UNSIGNED",    
  "error",         "input",         "ecmd",          "explain",     
  "cmdx",          "cmd",           "savepoint_opt",  "nm",          
  "create_table",  "create_table_args",  "with_opts",     "create_table_end",
  "createkw",      "ifnotexists",   "columnlist",    "engine_opts", 
  "tcons",         "columnname",    "carglist",      "autoinc",     
  "typedef",       "ccons",         "cconsname",     "term",        
  "expr",          "onconf",        "sortorder",     "check_constraint_def",
  "eidlist_opt",   "matcharg",      "refargs",       "defer_subclause",
  "refact_update",  "refact_delete",  "refact",        "init_deferred_pred_opt",
  "col_list_with_autoinc",  "sortlist",      "eidlist",       "defer_subclause_opt",
  "index_onconf",  "orconf",        "resolvetype",   "raisetype",   
  "ifexists",      "fullname",      "select",        "selectnowith",
  "oneselect",     "with",          "multiselect_op",  "distinct",    
  "selcollist",    "from",          "where_opt",     "groupby_opt", 
  "having_opt",    "orderby_opt",   "limit_opt",     "values",      
  "nexprlist",     "exprlist",      "sclp",          "as",          
  "seltablist",    "stl_prefix",    "joinop",        "indexed_opt", 
  "on_opt",        "using_opt",     "join_nm",       "idlist",      
  "enable",        "setlist",       "insert_cmd",    "idlist_opt",  
  "trim_operands",  "trim_from_clause",  "trim_specification",  "expr_optional",
  "type_func",     "likeop",        "between_op",    "in_op",       
  "paren_exprlist",  "case_exprlist",  "case_else",     "uniqueflag",  
  "trigger_decl",  "trigger_cmd_list",  "trigger_time",  "trigger_event",
  "foreach_clause",  "when_clause",   "trigger_cmd",   "trnm",        
  "tridxby",       "alter_table_start",  "alter_add_constraint",  "unique_spec", 
  "wqlist",        "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "engine_opts ::= ENGINE EQ STRING",
 /*  15 */ "create_table_end ::=",
 /*  16 */ "columnlist ::= columnlist COMMA columnname carglist autoinc",
 /*  17 */ "columnlist ::= columnname carglist autoinc",
 /*  18 */ "columnname ::= nm typedef",
 /*  19 */ "nm ::= ID|INDEXED",
 /*  20 */ "cconsname ::= CONSTRAINT nm",
 /*  21 */ "cconsname ::=",
 /*  22 */ "ccons ::= DEFAULT term",
 /*  23 */ "ccons ::= DEFAULT LP expr RP",
 /*  24 */ "ccons ::= DEFAULT PLUS term",
 /*  25 */ "ccons ::= DEFAULT MINUS term",
 /*  26 */ "ccons ::= NULL onconf",
 /*  27 */ "ccons ::= NOT NULL onconf",
 /*  28 */ "ccons ::= cconsname PRIMARY KEY sortorder",
 /*  29 */ "ccons ::= cconsname UNIQUE",
 /*  30 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  31 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  32 */ "ccons ::= defer_subclause",
 /*  33 */ "ccons ::= COLLATE ID|INDEXED",
 /*  34 */ "autoinc ::=",
 /*  35 */ "autoinc ::= AUTOINCR",
 /*  36 */ "refargs ::= refact_update",
 /*  37 */ "refargs ::= refact_delete",
 /*  38 */ "refargs ::= refact_delete refact_update",
 /*  39 */ "refargs ::= refact_update refact_delete",
 /*  40 */ "refargs ::=",
 /*  41 */ "refact_update ::= ON UPDATE refact",
 /*  42 */ "refact_delete ::= ON DELETE refact",
 /*  43 */ "matcharg ::= MATCH SIMPLE",
 /*  44 */ "matcharg ::= MATCH PARTIAL",
 /*  45 */ "matcharg ::= MATCH FULL",
 /*  46 */ "matcharg ::=",
 /*  47 */ "refact ::= SET NULL",
 /*  48 */ "refact ::= SET DEFAULT",
 /*  49 */ "refact ::= CASCADE",
 /*  50 */ "refact ::= RESTRICT",
 /*  51 */ "refact ::= NO ACTION",
 /*  52 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  53 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  54 */ "init_deferred_pred_opt ::=",
 /*  55 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  56 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  57 */ "tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP",
 /*  58 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  59 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  60 */ "defer_subclause_opt ::=",
 /*  61 */ "onconf ::=",
 /*  62 */ "onconf ::= ON CONFLICT resolvetype",
 /*  63 */ "orconf ::=",
 /*  64 */ "orconf ::= OR resolvetype",
 /*  65 */ "resolvetype ::= IGNORE",
 /*  66 */ "resolvetype ::= REPLACE",
 /*  67 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  68 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  69 */ "ifexists ::= IF EXISTS",
 /*  70 */ "ifexists ::=",
 /*  71 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  72 */ "cmd ::= select",
 /*  73 */ "select ::= with selectnowith",
 /*  74 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  75 */ "multiselect_op ::= UNION",
 /*  76 */ "multiselect_op ::= UNION ALL",
 /*  77 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  78 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  79 */ "values ::= VALUES LP nexprlist RP",
 /*  80 */ "values ::= values COMMA LP exprlist RP",
 /*  81 */ "distinct ::= DISTINCT",
 /*  82 */ "distinct ::= ALL",
 /*  83 */ "distinct ::=",
 /*  84 */ "sclp ::=",
 /*  85 */ "selcollist ::= sclp expr as",
 /*  86 */ "selcollist ::= sclp STAR",
 /*  87 */ "selcollist ::= sclp nm DOT STAR",
 /*  88 */ "as ::= AS nm",
 /*  89 */ "as ::=",
 /*  90 */ "from ::=",
 /*  91 */ "from ::= FROM seltablist",
 /*  92 */ "stl_prefix ::= seltablist joinop",
 /*  93 */ "stl_prefix ::=",
 /*  94 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  95 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  96 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  97 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  98 */ "fullname ::= nm",
 /*  99 */ "joinop ::= COMMA|JOIN",
 /* 100 */ "joinop ::= JOIN_KW JOIN",
 /* 101 */ "joinop ::= JOIN_KW join_nm JOIN",
 /* 102 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 103 */ "on_opt ::= ON expr",
 /* 104 */ "on_opt ::=",
 /* 105 */ "indexed_opt ::=",
 /* 106 */ "indexed_opt ::= INDEXED BY nm",
 /* 107 */ "indexed_opt ::= NOT INDEXED",
 /* 108 */ "using_opt ::= USING LP idlist RP",
 /* 109 */ "using_opt ::=",
 /* 110 */ "orderby_opt ::=",
 /* 111 */ "orderby_opt ::= ORDER BY sortlist",
 /* 112 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 113 */ "sortlist ::= expr sortorder",
 /* 114 */ "col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc",
 /* 115 */ "col_list_with_autoinc ::= expr autoinc",
 /* 116 */ "enable ::= ENABLE",
 /* 117 */ "enable ::= DISABLE",
 /* 118 */ "sortorder ::= ASC",
 /* 119 */ "sortorder ::= DESC",
 /* 120 */ "sortorder ::=",
 /* 121 */ "groupby_opt ::=",
 /* 122 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 123 */ "having_opt ::=",
 /* 124 */ "having_opt ::= HAVING expr",
 /* 125 */ "limit_opt ::=",
 /* 126 */ "limit_opt ::= LIMIT expr",
 /* 127 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 128 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 129 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 130 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 131 */ "where_opt ::=",
 /* 132 */ "where_opt ::= WHERE expr",
 /* 133 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 134 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 135 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 136 */ "setlist ::= nm EQ expr",
 /* 137 */ "setlist ::= LP idlist RP EQ expr",
 /* 138 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 139 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 140 */ "insert_cmd ::= INSERT orconf",
 /* 141 */ "insert_cmd ::= REPLACE",
 /* 142 */ "idlist_opt ::=",
 /* 143 */ "idlist_opt ::= LP idlist RP",
 /* 144 */ "idlist ::= idlist COMMA nm",
 /* 145 */ "idlist ::= nm",
 /* 146 */ "expr ::= LP expr RP",
 /* 147 */ "term ::= NULL",
 /* 148 */ "expr ::= ID|INDEXED",
 /* 149 */ "expr ::= JOIN_KW",
 /* 150 */ "expr ::= nm DOT nm",
 /* 151 */ "term ::= FLOAT|BLOB",
 /* 152 */ "term ::= STRING",
 /* 153 */ "term ::= FALSE",
 /* 154 */ "term ::= TRUE",
 /* 155 */ "term ::= UNKNOWN",
 /* 156 */ "term ::= INTEGER",
 /* 157 */ "expr ::= VARIABLE",
 /* 158 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 159 */ "expr ::= CAST LP expr AS typedef RP",
 /* 160 */ "expr ::= TRIM LP trim_operands RP",
 /* 161 */ "trim_operands ::= trim_from_clause expr",
 /* 162 */ "trim_operands ::= expr",
 /* 163 */ "trim_from_clause ::= expr FROM",
 /* 164 */ "trim_from_clause ::= trim_specification expr_optional FROM",
 /* 165 */ "expr_optional ::=",
 /* 166 */ "expr_optional ::= expr",
 /* 167 */ "trim_specification ::= LEADING",
 /* 168 */ "trim_specification ::= TRAILING",
 /* 169 */ "trim_specification ::= BOTH",
 /* 170 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 171 */ "expr ::= type_func LP distinct exprlist RP",
 /* 172 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 173 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 174 */ "expr ::= expr AND expr",
 /* 175 */ "expr ::= expr OR expr",
 /* 176 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 177 */ "expr ::= expr EQ|NE expr",
 /* 178 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 179 */ "expr ::= expr PLUS|MINUS expr",
 /* 180 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 181 */ "expr ::= expr CONCAT expr",
 /* 182 */ "likeop ::= LIKE_KW|MATCH",
 /* 183 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 184 */ "expr ::= expr likeop expr",
 /* 185 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 186 */ "expr ::= expr IS NULL",
 /* 187 */ "expr ::= expr IS NOT NULL",
 /* 188 */ "expr ::= NOT expr",
 /* 189 */ "expr ::= BITNOT expr",
 /* 190 */ "expr ::= MINUS expr",
 /* 191 */ "expr ::= PLUS expr",
 /* 192 */ "between_op ::= BETWEEN",
 /* 193 */ "between_op ::= NOT BETWEEN",
 /* 194 */ "expr ::= expr between_op expr AND expr",
 /* 195 */ "in_op ::= IN",
 /* 196 */ "in_op ::= NOT IN",
 /* 197 */ "expr ::= expr in_op LP exprlist RP",
 /* 198 */ "expr ::= LP select RP",
 /* 199 */ "expr ::= expr in_op LP select RP",
 /* 200 */ "expr ::= expr in_op nm paren_exprlist",
 /* 201 */ "expr ::= EXISTS LP select RP",
 /* 202 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 203 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 204 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 205 */ "case_else ::= ELSE expr",
 /* 206 */ "case_else ::=",
 /* 207 */ "exprlist ::=",
 /* 208 */ "nexprlist ::= nexprlist COMMA expr",
 /* 209 */ "nexprlist ::= expr",
 /* 210 */ "paren_exprlist ::=",
 /* 211 */ "paren_exprlist ::= LP exprlist RP",
 /* 212 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 213 */ "uniqueflag ::= UNIQUE",
 /* 214 */ "uniqueflag ::=",
 /* 215 */ "eidlist_opt ::=",
 /* 216 */ "eidlist_opt ::= LP eidlist RP",
 /* 217 */ "eidlist ::= eidlist COMMA nm",
 /* 218 */ "eidlist ::= nm",
 /* 219 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 220 */ "cmd ::= SET SESSION nm EQ term",
 /* 221 */ "cmd ::= PRAGMA nm",
 /* 222 */ "cmd ::= PRAGMA nm LP nm RP",
 /* 223 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 224 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 225 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 226 */ "trigger_time ::= BEFORE",
 /* 227 */ "trigger_time ::= AFTER",
 /* 228 */ "trigger_time ::= INSTEAD OF",
 /* 229 */ "trigger_time ::=",
 /* 230 */ "trigger_event ::= DELETE|INSERT",
 /* 231 */ "trigger_event ::= UPDATE",
 /* 232 */ "trigger_event ::= UPDATE OF idlist",
 /* 233 */ "foreach_clause ::=",
 /* 234 */ "when_clause ::=",
 /* 235 */ "when_clause ::= WHEN expr",
 /* 236 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 237 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 238 */ "trnm ::= nm DOT nm",
 /* 239 */ "tridxby ::= INDEXED BY nm",
 /* 240 */ "tridxby ::= NOT INDEXED",
 /* 241 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 242 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 243 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 244 */ "trigger_cmd ::= select",
 /* 245 */ "expr ::= RAISE LP IGNORE RP",
 /* 246 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 247 */ "raisetype ::= ROLLBACK",
 /* 248 */ "raisetype ::= ABORT",
 /* 249 */ "raisetype ::= FAIL",
 /* 250 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 251 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 252 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 253 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 254 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 255 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 256 */ "unique_spec ::= UNIQUE",
 /* 257 */ "unique_spec ::= PRIMARY KEY",
 /* 258 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 259 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 260 */ "cmd ::= alter_table_start enable CHECK CONSTRAINT nm",
 /* 261 */ "with ::=",
 /* 262 */ "with ::= WITH wqlist",
 /* 263 */ "with ::= WITH RECURSIVE wqlist",
 /* 264 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 265 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 266 */ "typedef ::= TEXT",
 /* 267 */ "typedef ::= STRING_KW",
 /* 268 */ "typedef ::= SCALAR",
 /* 269 */ "typedef ::= BOOL",
 /* 270 */ "typedef ::= BOOLEAN",
 /* 271 */ "typedef ::= VARBINARY",
 /* 272 */ "char_len ::= LP INTEGER RP",
 /* 273 */ "typedef ::= VARCHAR char_len",
 /* 274 */ "number_typedef ::= NUMBER",
 /* 275 */ "number_typedef ::= DOUBLE",
 /* 276 */ "number_typedef ::= INT|INTEGER_KW",
 /* 277 */ "number_typedef ::= UNSIGNED",
 /* 278 */ "input ::= ecmd",
 /* 279 */ "explain ::=",
 /* 280 */ "cmdx ::= cmd",
 /* 281 */ "savepoint_opt ::= SAVEPOINT",
 /* 282 */ "savepoint_opt ::=",
 /* 283 */ "cmd ::= create_table create_table_args with_opts create_table_end",
 /* 284 */ "create_table_args ::= LP columnlist RP",
 /* 285 */ "with_opts ::= WITH engine_opts",
 /* 286 */ "with_opts ::=",
 /* 287 */ "columnlist ::= columnlist COMMA tcons",
 /* 288 */ "columnlist ::= tcons",
 /* 289 */ "carglist ::= carglist ccons",
 /* 290 */ "carglist ::=",
 /* 291 */ "ccons ::= check_constraint_def",
 /* 292 */ "tcons ::= check_constraint_def",
 /* 293 */ "defer_subclause_opt ::= defer_subclause",
 /* 294 */ "resolvetype ::= raisetype",
 /* 295 */ "selectnowith ::= oneselect",
 /* 296 */ "oneselect ::= values",
 /* 297 */ "sclp ::= selcollist COMMA",
 /* 298 */ "as ::= ID|STRING",
 /* 299 */ "join_nm ::= ID|INDEXED",
 /* 300 */ "join_nm ::= JOIN_KW",
 /* 301 */ "expr ::= term",
 /* 302 */ "type_func ::= CHAR",
 /* 303 */ "exprlist ::= nexprlist",
 /* 304 */ "foreach_clause ::= FOR EACH ROW",
 /* 305 */ "trnm ::= nm",
 /* 306 */ "tridxby ::=",
 /* 307 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 183: /* term */
    case 184: /* expr */
{
#line 953 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy66).pExpr, false);
#line 1577 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 188: /* eidlist_opt */
    case 196: /* col_list_with_autoinc */
    case 197: /* sortlist */
    case 198: /* eidlist */
    case 212: /* selcollist */
    case 215: /* groupby_opt */
    case 217: /* orderby_opt */
    case 220: /* nexprlist */
    case 221: /* exprlist */
    case 222: /* sclp */
    case 233: /* setlist */
    case 244: /* paren_exprlist */
    case 245: /* case_exprlist */
{
#line 1507 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy294));
#line 1596 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 205: /* fullname */
    case 213: /* from */
    case 224: /* seltablist */
    case 225: /* stl_prefix */
{
#line 702 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy323));
#line 1606 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 206: /* select */
    case 207: /* selectnowith */
    case 208: /* oneselect */
    case 219: /* values */
{
#line 464 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy297));
#line 1616 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 209: /* with */
    case 260: /* wqlist */
{
#line 1786 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy203));
#line 1624 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 214: /* where_opt */
    case 216: /* having_opt */
    case 228: /* on_opt */
    case 246: /* case_else */
    case 253: /* when_clause */
{
#line 862 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy60), false);
#line 1635 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 229: /* using_opt */
    case 231: /* idlist */
    case 235: /* idlist_opt */
{
#line 745 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy206));
#line 1644 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 236: /* trim_operands */
    case 237: /* trim_from_clause */
{
#line 1124 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy475));
#line 1652 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 239: /* expr_optional */
{
#line 1155 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy81), false);
#line 1659 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 249: /* trigger_cmd_list */
    case 254: /* trigger_cmd */
{
#line 1606 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy191));
#line 1667 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
    case 251: /* trigger_event */
{
#line 1587 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy330).b);
#line 1674 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 44 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1850 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 162, 3 },
  { 162, 1 },
  { 163, 1 },
  { 163, 3 },
  { 165, 2 },
  { 165, 1 },
  { 165, 1 },
  { 165, 2 },
  { 165, 3 },
  { 165, 4 },
  { 168, 4 },
  { 172, 1 },
  { 173, 0 },
  { 173, 3 },
  { 175, 3 },
  { 171, 0 },
  { 174, 5 },
  { 174, 3 },
  { 177, 2 },
  { 167, 1 },
  { 182, 2 },
  { 182, 0 },
  { 181, 2 },
  { 181, 4 },
  { 181, 3 },
  { 181, 3 },
  { 181, 2 },
  { 181, 3 },
  { 181, 4 },
  { 181, 2 },
  { 187, 5 },
  { 181, 6 },
  { 181, 1 },
  { 181, 2 },
  { 179, 0 },
  { 179, 1 },
  { 190, 1 },
  { 190, 1 },
  { 190, 2 },
  { 190, 2 },
  { 190, 0 },
  { 192, 3 },
  { 193, 3 },
  { 189, 2 },
  { 189, 2 },
  { 189, 2 },
  { 189, 0 },
  { 194, 2 },
  { 194, 2 },
  { 194, 1 },
  { 194, 1 },
  { 194, 2 },
  { 191, 3 },
  { 191, 2 },
  { 195, 0 },
  { 195, 2 },
  { 195, 2 },
  { 176, 6 },
  { 176, 5 },
  { 176, 12 },
  { 199, 0 },
  { 185, 0 },
  { 185, 3 },
  { 201, 0 },
  { 201, 2 },
  { 202, 1 },
  { 202, 1 },
  { 165, 4 },
  { 165, 4 },
  { 204, 2 },
  { 204, 0 },
  { 165, 7 },
  { 165, 1 },
  { 206, 2 },
  { 207, 3 },
  { 210, 1 },
  { 210, 2 },
  { 210, 1 },
  { 208, 9 },
  { 219, 4 },
  { 219, 5 },
  { 211, 1 },
  { 211, 1 },
  { 211, 0 },
  { 222, 0 },
  { 212, 3 },
  { 212, 2 },
  { 212, 4 },
  { 223, 2 },
  { 223, 0 },
  { 213, 0 },
  { 213, 2 },
  { 225, 2 },
  { 225, 0 },
  { 224, 6 },
  { 224, 8 },
  { 224, 7 },
  { 224, 7 },
  { 205, 1 },
  { 226, 1 },
  { 226, 2 },
  { 226, 3 },
  { 226, 4 },
  { 228, 2 },
  { 228, 0 },
  { 227, 0 },
  { 227, 3 },
  { 227, 2 },
  { 229, 4 },
  { 229, 0 },
  { 217, 0 },
  { 217, 3 },
  { 197, 4 },
  { 197, 2 },
  { 196, 4 },
  { 196, 2 },
  { 232, 1 },
  { 232, 1 },
  { 186, 1 },
  { 186, 1 },
  { 186, 0 },
  { 215, 0 },
  { 215, 3 },
  { 216, 0 },
  { 216, 2 },
  { 218, 0 },
  { 218, 2 },
  { 218, 4 },
  { 218, 4 },
  { 165, 6 },
  { 165, 3 },
  { 214, 0 },
  { 214, 2 },
  { 165, 8 },
  { 233, 5 },
  { 233, 7 },
  { 233, 3 },
  { 233, 5 },
  { 165, 6 },
  { 165, 7 },
  { 234, 2 },
  { 234, 1 },
  { 235, 0 },
  { 235, 3 },
  { 231, 3 },
  { 231, 1 },
  { 184, 3 },
  { 183, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 3 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 183, 1 },
  { 184, 1 },
  { 184, 3 },
  { 184, 6 },
  { 184, 4 },
  { 236, 2 },
  { 236, 1 },
  { 237, 2 },
  { 237, 3 },
  { 239, 0 },
  { 239, 1 },
  { 238, 1 },
  { 238, 1 },
  { 238, 1 },
  { 184, 5 },
  { 184, 5 },
  { 184, 4 },
  { 184, 5 },
  { 184, 3 },
  { 184, 3 },
  { 184, 3 },
  { 184, 3 },
  { 184, 3 },
  { 184, 3 },
  { 184, 3 },
  { 184, 3 },
  { 241, 1 },
  { 241, 2 },
  { 184, 3 },
  { 184, 5 },
  { 184, 3 },
  { 184, 4 },
  { 184, 2 },
  { 184, 2 },
  { 184, 2 },
  { 184, 2 },
  { 242, 1 },
  { 242, 2 },
  { 184, 5 },
  { 243, 1 },
  { 243, 2 },
  { 184, 5 },
  { 184, 3 },
  { 184, 5 },
  { 184, 4 },
  { 184, 4 },
  { 184, 5 },
  { 245, 5 },
  { 245, 4 },
  { 246, 2 },
  { 246, 0 },
  { 221, 0 },
  { 220, 3 },
  { 220, 1 },
  { 244, 0 },
  { 244, 3 },
  { 165, 10 },
  { 247, 1 },
  { 247, 0 },
  { 188, 0 },
  { 188, 3 },
  { 198, 3 },
  { 198, 1 },
  { 165, 6 },
  { 165, 5 },
  { 165, 2 },
  { 165, 5 },
  { 165, 7 },
  { 165, 5 },
  { 248, 9 },
  { 250, 1 },
  { 250, 1 },
  { 250, 2 },
  { 250, 0 },
  { 251, 1 },
  { 251, 1 },
  { 251, 3 },
  { 252, 0 },
  { 253, 0 },
  { 253, 2 },
  { 249, 3 },
  { 249, 2 },
  { 255, 3 },
  { 256, 3 },
  { 256, 2 },
  { 254, 7 },
  { 254, 5 },
  { 254, 5 },
  { 254, 1 },
  { 184, 4 },
  { 184, 6 },
  { 203, 1 },
  { 203, 1 },
  { 203, 1 },
  { 165, 4 },
  { 257, 3 },
  { 258, 4 },
  { 165, 12 },
  { 165, 5 },
  { 165, 5 },
  { 259, 1 },
  { 259, 2 },
  { 165, 4 },
  { 165, 6 },
  { 165, 5 },
  { 209, 0 },
  { 209, 2 },
  { 209, 3 },
  { 260, 6 },
  { 260, 8 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 180, 1 },
  { 261, 3 },
  { 180, 2 },
  { 262, 1 },
  { 262, 1 },
  { 262, 1 },
  { 262, 1 },
  { 161, 1 },
  { 163, 0 },
  { 164, 1 },
  { 166, 1 },
  { 166, 0 },
  { 165, 4 },
  { 169, 3 },
  { 170, 2 },
  { 170, 0 },
  { 174, 3 },
  { 174, 1 },
  { 178, 2 },
  { 178, 0 },
  { 181, 1 },
  { 176, 1 },
  { 199, 1 },
  { 202, 1 },
  { 207, 1 },
  { 208, 1 },
  { 222, 2 },
  { 223, 1 },
  { 230, 1 },
  { 230, 1 },
  { 184, 1 },
  { 240, 1 },
  { 221, 1 },
  { 252, 3 },
  { 255, 1 },
  { 256, 0 },
  { 180, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 123 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2301 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 127 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2309 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 132 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2314 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 133 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2319 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 163 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2324 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 164 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2329 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 165 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2334 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 169 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2341 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 172 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2348 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 175 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2355 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 182 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy20);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2364 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 187 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2369 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 34: /* autoinc ::= */ yytestcase(yyruleno==34);
      case 54: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==54);
      case 60: /* defer_subclause_opt ::= */ yytestcase(yyruleno==60);
      case 70: /* ifexists ::= */ yytestcase(yyruleno==70);
      case 83: /* distinct ::= */ yytestcase(yyruleno==83);
#line 190 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy20 = 0;}
#line 2379 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 191 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy20 = 1;}
#line 2384 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 14: /* engine_opts ::= ENGINE EQ STRING */
#line 198 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  /* Note that specifying engine clause overwrites default engine. */
  if (yymsp[0].minor.yy0.n > ENGINE_NAME_MAX) {
    diag_set(ClientError, ER_CREATE_SPACE,
             pParse->create_table_def.new_space->def->name,
             "space engine name is too long");
    pParse->is_aborted = true;
    return;
  }
  /* Need to dequote name. */
  char *normalized_name = sql_name_from_token(pParse->db, &yymsp[0].minor.yy0);
  if (normalized_name == NULL)
    return;
  memcpy(pParse->create_table_def.new_space->def->engine_name, normalized_name,
         strlen(normalized_name) + 1);
  sqlDbFree(pParse->db, normalized_name);
}
#line 2405 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 15: /* create_table_end ::= */
#line 216 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ sqlEndTable(pParse); }
#line 2410 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 16: /* columnlist ::= columnlist COMMA columnname carglist autoinc */
      case 17: /* columnlist ::= columnname carglist autoinc */ yytestcase(yyruleno==17);
#line 229 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  uint32_t fieldno = pParse->create_table_def.new_space->def->field_count - 1;
  if (yymsp[0].minor.yy20 == 1 && sql_add_autoincrement(pParse, fieldno) != 0)
    return;
}
#line 2420 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 18: /* columnname ::= nm typedef */
#line 241 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{sqlAddColumn(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy302);}
#line 2425 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 19: /* nm ::= ID|INDEXED */
#line 276 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2436 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 20: /* cconsname ::= CONSTRAINT nm */
#line 290 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy451 = yymsp[0].minor.yy0; }
#line 2441 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 21: /* cconsname ::= */
#line 291 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[1].minor.yy451 = Token_nil; }
#line 2446 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 22: /* ccons ::= DEFAULT term */
      case 24: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==24);
#line 292 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy66);}
#line 2452 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 23: /* ccons ::= DEFAULT LP expr RP */
#line 293 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy66);}
#line 2457 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 25: /* ccons ::= DEFAULT MINUS term */
#line 295 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy66.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy66.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2468 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 26: /* ccons ::= NULL onconf */
#line 306 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy20 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy20);
}
#line 2478 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 27: /* ccons ::= NOT NULL onconf */
#line 312 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy20);}
#line 2483 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 28: /* ccons ::= cconsname PRIMARY KEY sortorder */
#line 313 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-3].minor.yy451, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[0].minor.yy20, false);
  sqlAddPrimaryKey(pParse);
}
#line 2492 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 29: /* ccons ::= cconsname UNIQUE */
#line 318 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy451, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2502 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 30: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 327 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy451, &yymsp[-1].minor.yy66);
  sql_create_check_contraint(pParse);
}
#line 2510 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 31: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 332 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy451, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy294, yymsp[-1].minor.yy20, yymsp[0].minor.yy20,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2519 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 32: /* ccons ::= defer_subclause */
#line 337 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy20);}
#line 2524 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 33: /* ccons ::= COLLATE ID|INDEXED */
#line 338 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2529 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 35: /* autoinc ::= AUTOINCR */
#line 343 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = 1;}
#line 2534 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 36: /* refargs ::= refact_update */
#line 351 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yylhsminor.yy20 = (yymsp[0].minor.yy20 << 8); }
#line 2539 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy20 = yylhsminor.yy20;
        break;
      case 37: /* refargs ::= refact_delete */
#line 352 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yylhsminor.yy20 = yymsp[0].minor.yy20; }
#line 2545 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy20 = yylhsminor.yy20;
        break;
      case 38: /* refargs ::= refact_delete refact_update */
#line 353 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yylhsminor.yy20 = (yymsp[0].minor.yy20 << 8) | (yymsp[-1].minor.yy20) ; }
#line 2551 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-1].minor.yy20 = yylhsminor.yy20;
        break;
      case 39: /* refargs ::= refact_update refact_delete */
#line 354 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yylhsminor.yy20 = (yymsp[-1].minor.yy20 << 8) | (yymsp[0].minor.yy20) ; }
#line 2557 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-1].minor.yy20 = yylhsminor.yy20;
        break;
      case 40: /* refargs ::= */
#line 355 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[1].minor.yy20 = 0; }
#line 2563 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 41: /* refact_update ::= ON UPDATE refact */
      case 42: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==42);
#line 358 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-2].minor.yy20 = yymsp[0].minor.yy20; }
#line 2569 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 43: /* matcharg ::= MATCH SIMPLE */
#line 363 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = FKEY_MATCH_SIMPLE; }
#line 2574 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 44: /* matcharg ::= MATCH PARTIAL */
#line 364 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = FKEY_MATCH_PARTIAL; }
#line 2579 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 45: /* matcharg ::= MATCH FULL */
#line 365 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = FKEY_MATCH_FULL; }
#line 2584 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 46: /* matcharg ::= */
#line 366 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[1].minor.yy20 = FKEY_MATCH_SIMPLE; }
#line 2589 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 47: /* refact ::= SET NULL */
#line 369 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = FKEY_ACTION_SET_NULL; }
#line 2594 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 48: /* refact ::= SET DEFAULT */
#line 370 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = FKEY_ACTION_SET_DEFAULT; }
#line 2599 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 49: /* refact ::= CASCADE */
#line 371 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy20 = FKEY_ACTION_CASCADE; }
#line 2604 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 50: /* refact ::= RESTRICT */
#line 372 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy20 = FKEY_ACTION_RESTRICT; }
#line 2609 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 51: /* refact ::= NO ACTION */
#line 373 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = FKEY_NO_ACTION; }
#line 2614 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 52: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 375 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy20 = 0;}
#line 2619 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 53: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 64: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==64);
      case 140: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==140);
#line 376 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy20 = yymsp[0].minor.yy20;}
#line 2626 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 55: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 69: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==69);
      case 193: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==193);
      case 196: /* in_op ::= NOT IN */ yytestcase(yyruleno==196);
#line 379 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy20 = 1;}
#line 2634 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 56: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 380 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy20 = 0;}
#line 2639 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 57: /* tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP */
#line 382 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-5].minor.yy451, yymsp[-1].minor.yy294,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2648 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 58: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 387 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy451, yymsp[-1].minor.yy294,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2658 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 59: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 395 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy451, yymsp[-7].minor.yy294, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy294, yymsp[-2].minor.yy20, yymsp[-1].minor.yy20, yymsp[0].minor.yy20);
  sql_create_foreign_key(pParse);
}
#line 2666 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 61: /* onconf ::= */
#line 410 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy20 = ON_CONFLICT_ACTION_ABORT;}
#line 2671 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 62: /* onconf ::= ON CONFLICT resolvetype */
#line 411 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy20 = yymsp[0].minor.yy20;}
#line 2676 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 63: /* orconf ::= */
#line 412 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy20 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2681 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 65: /* resolvetype ::= IGNORE */
#line 415 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = ON_CONFLICT_ACTION_IGNORE;}
#line 2686 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 66: /* resolvetype ::= REPLACE */
      case 141: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==141);
#line 416 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = ON_CONFLICT_ACTION_REPLACE;}
#line 2692 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 67: /* cmd ::= DROP TABLE ifexists fullname */
#line 421 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy323, &t, yymsp[-1].minor.yy20);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2702 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 68: /* cmd ::= DROP VIEW ifexists fullname */
#line 428 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy323, &t, yymsp[-1].minor.yy20);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2712 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 71: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 442 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy294, yymsp[0].minor.yy297, yymsp[-4].minor.yy20);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy297);
  }
}
#line 2725 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 72: /* cmd ::= select */
#line 454 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy297, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy297);
  sql_select_delete(pParse->db, yymsp[0].minor.yy297);
}
#line 2737 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 73: /* select ::= with selectnowith */
#line 497 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy297;
  if( p ){
    p->pWith = yymsp[-1].minor.yy203;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy203);
  }
  yymsp[-1].minor.yy297 = p; /*A-overwrites-W*/
}
#line 2751 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 74: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 510 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy297;
  Select *pLhs = yymsp[-2].minor.yy297;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy20;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy20!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy297 = pRhs;
}
#line 2777 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 75: /* multiselect_op ::= UNION */
      case 77: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==77);
#line 533 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2783 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 76: /* multiselect_op ::= UNION ALL */
#line 534 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy20 = TK_ALL;}
#line 2788 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 78: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 538 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy520.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy294);
  yymsp[-8].minor.yy297 = sqlSelectNew(pParse,yymsp[-6].minor.yy294,yymsp[-5].minor.yy323,yymsp[-4].minor.yy60,yymsp[-3].minor.yy294,yymsp[-2].minor.yy60,yymsp[-1].minor.yy294,yymsp[-7].minor.yy20,yymsp[0].minor.yy520.pLimit,yymsp[0].minor.yy520.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy297!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy297->zSelName), yymsp[-8].minor.yy297->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy297->zSelName), yymsp[-8].minor.yy297->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2824 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 79: /* values ::= VALUES LP nexprlist RP */
#line 574 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy297 = sqlSelectNew(pParse,yymsp[-1].minor.yy294,0,0,0,0,0,SF_Values,0,0);
}
#line 2831 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 80: /* values ::= values COMMA LP exprlist RP */
#line 577 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy297;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy294,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy297 = pRight;
  }else{
    yymsp[-4].minor.yy297 = pLeft;
  }
}
#line 2847 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 81: /* distinct ::= DISTINCT */
#line 594 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = SF_Distinct;}
#line 2852 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 82: /* distinct ::= ALL */
#line 595 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = SF_All;}
#line 2857 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 84: /* sclp ::= */
      case 110: /* orderby_opt ::= */ yytestcase(yyruleno==110);
      case 121: /* groupby_opt ::= */ yytestcase(yyruleno==121);
      case 207: /* exprlist ::= */ yytestcase(yyruleno==207);
      case 210: /* paren_exprlist ::= */ yytestcase(yyruleno==210);
      case 215: /* eidlist_opt ::= */ yytestcase(yyruleno==215);
#line 608 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy294 = 0;}
#line 2867 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 85: /* selcollist ::= sclp expr as */
#line 609 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy294 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy294, yymsp[-1].minor.yy66.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy294, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy294,&yymsp[-1].minor.yy66);
}
#line 2876 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 86: /* selcollist ::= sclp STAR */
#line 614 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy294 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy294, p);
}
#line 2888 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 87: /* selcollist ::= sclp nm DOT STAR */
#line 622 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy294 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy294, pDot);
}
#line 2902 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 88: /* as ::= AS nm */
#line 637 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2907 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 89: /* as ::= */
#line 639 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2912 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 90: /* from ::= */
#line 651 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy323 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy323));}
#line 2917 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 91: /* from ::= FROM seltablist */
#line 652 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy323 = yymsp[0].minor.yy323;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy323);
}
#line 2925 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 92: /* stl_prefix ::= seltablist joinop */
#line 660 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy323 && yymsp[-1].minor.yy323->nSrc>0) ) yymsp[-1].minor.yy323->a[yymsp[-1].minor.yy323->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy20;
}
#line 2932 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 93: /* stl_prefix ::= */
#line 663 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy323 = 0;}
#line 2937 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 665 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy323 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy323,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy60,yymsp[0].minor.yy206);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy323, &yymsp[-2].minor.yy0);
}
#line 2945 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 95: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 670 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy323 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy323,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy60,yymsp[0].minor.yy206);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy323, yymsp[-4].minor.yy294);
}
#line 2953 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 96: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 675 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy323 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy323,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy297,yymsp[-1].minor.yy60,yymsp[0].minor.yy206);
}
#line 2960 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 97: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 679 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy323==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy60==0 && yymsp[0].minor.yy206==0 ){
    yymsp[-6].minor.yy323 = yymsp[-4].minor.yy323;
  }else if( yymsp[-4].minor.yy323->nSrc==1 ){
    yymsp[-6].minor.yy323 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy323,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy60,yymsp[0].minor.yy206);
    if( yymsp[-6].minor.yy323 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy323->a[yymsp[-6].minor.yy323->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy323->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy323);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy323);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy323,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy323 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy323,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy60,yymsp[0].minor.yy206);
  }
}
#line 2985 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 98: /* fullname ::= nm */
#line 703 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  /* yylhsminor.yy323-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy323 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy323 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 2997 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy323 = yylhsminor.yy323;
        break;
      case 99: /* joinop ::= COMMA|JOIN */
#line 716 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy20 = JT_INNER; }
#line 3003 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 100: /* joinop ::= JOIN_KW JOIN */
#line 718 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy20 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 3008 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 101: /* joinop ::= JOIN_KW join_nm JOIN */
#line 720 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy20 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 3013 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 102: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 722 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-3].minor.yy20 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 3018 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 103: /* on_opt ::= ON expr */
      case 124: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==124);
      case 132: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==132);
      case 205: /* case_else ::= ELSE expr */ yytestcase(yyruleno==205);
#line 726 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy60 = yymsp[0].minor.yy66.pExpr;}
#line 3026 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 104: /* on_opt ::= */
      case 123: /* having_opt ::= */ yytestcase(yyruleno==123);
      case 131: /* where_opt ::= */ yytestcase(yyruleno==131);
      case 206: /* case_else ::= */ yytestcase(yyruleno==206);
#line 727 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy60 = 0;}
#line 3034 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 105: /* indexed_opt ::= */
#line 740 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3039 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 106: /* indexed_opt ::= INDEXED BY nm */
#line 741 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3044 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 107: /* indexed_opt ::= NOT INDEXED */
#line 742 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3049 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 108: /* using_opt ::= USING LP idlist RP */
#line 746 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-3].minor.yy206 = yymsp[-1].minor.yy206;}
#line 3054 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 109: /* using_opt ::= */
      case 142: /* idlist_opt ::= */ yytestcase(yyruleno==142);
#line 747 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy206 = 0;}
#line 3060 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 111: /* orderby_opt ::= ORDER BY sortlist */
      case 122: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==122);
#line 761 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy294 = yymsp[0].minor.yy294;}
#line 3066 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 112: /* sortlist ::= sortlist COMMA expr sortorder */
#line 762 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy294 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy294,yymsp[-1].minor.yy66.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy294,yymsp[0].minor.yy20);
}
#line 3074 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 113: /* sortlist ::= expr sortorder */
#line 766 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  /* yylhsminor.yy294-overwrites-yymsp[-1].minor.yy66. */
  yylhsminor.yy294 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy66.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy294,yymsp[0].minor.yy20);
}
#line 3083 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-1].minor.yy294 = yylhsminor.yy294;
        break;
      case 114: /* col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc */
#line 780 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  uint32_t fieldno;
  if (yymsp[0].minor.yy20 == 1) {
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy66.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  yymsp[-3].minor.yy294 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy294, yymsp[-1].minor.yy66.pExpr);
}
#line 3098 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 115: /* col_list_with_autoinc ::= expr autoinc */
#line 791 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  if (yymsp[0].minor.yy20 == 1) {
    uint32_t fieldno = 0;
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy66.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  /* yylhsminor.yy294-overwrites-yymsp[-1].minor.yy66. */
  yylhsminor.yy294 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy66.pExpr);
}
#line 3113 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-1].minor.yy294 = yylhsminor.yy294;
        break;
      case 116: /* enable ::= ENABLE */
#line 804 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy371 = true;}
#line 3119 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 117: /* enable ::= DISABLE */
#line 805 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy371 = false;}
#line 3124 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 118: /* sortorder ::= ASC */
#line 809 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = SORT_ORDER_ASC;}
#line 3129 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 119: /* sortorder ::= DESC */
#line 810 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = SORT_ORDER_DESC;}
#line 3134 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 120: /* sortorder ::= */
#line 811 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy20 = SORT_ORDER_UNDEF;}
#line 3139 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 125: /* limit_opt ::= */
#line 836 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy520.pLimit = 0; yymsp[1].minor.yy520.pOffset = 0;}
#line 3144 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 126: /* limit_opt ::= LIMIT expr */
#line 837 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy520.pLimit = yymsp[0].minor.yy66.pExpr; yymsp[-1].minor.yy520.pOffset = 0;}
#line 3149 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 127: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 839 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-3].minor.yy520.pLimit = yymsp[-2].minor.yy66.pExpr; yymsp[-3].minor.yy520.pOffset = yymsp[0].minor.yy66.pExpr;}
#line 3154 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 128: /* limit_opt ::= LIMIT expr COMMA expr */
#line 841 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-3].minor.yy520.pOffset = yymsp[-2].minor.yy66.pExpr; yymsp[-3].minor.yy520.pLimit = yymsp[0].minor.yy66.pExpr;}
#line 3159 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 129: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 845 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy203, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy323, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy323,yymsp[0].minor.yy60);
}
#line 3171 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 130: /* cmd ::= TRUNCATE TABLE fullname */
#line 856 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy323);
}
#line 3179 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 133: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 870 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy203, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy323, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy294 != NULL && yymsp[-1].minor.yy294->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy294->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy323,yymsp[-1].minor.yy294,yymsp[0].minor.yy60,yymsp[-5].minor.yy20);
}
#line 3196 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 134: /* setlist ::= setlist COMMA nm EQ expr */
#line 887 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy294 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy294, yymsp[0].minor.yy66.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy294, &yymsp[-2].minor.yy0, 1);
}
#line 3204 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 135: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 891 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy294 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy294, yymsp[-3].minor.yy206, yymsp[0].minor.yy66.pExpr);
}
#line 3211 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 136: /* setlist ::= nm EQ expr */
#line 894 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yylhsminor.yy294 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy66.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy294, &yymsp[-2].minor.yy0, 1);
}
#line 3219 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-2].minor.yy294 = yylhsminor.yy294;
        break;
      case 137: /* setlist ::= LP idlist RP EQ expr */
#line 898 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy294 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy206, yymsp[0].minor.yy66.pExpr);
}
#line 3227 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 138: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 904 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy203, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy323, yymsp[0].minor.yy297, yymsp[-1].minor.yy206, yymsp[-4].minor.yy20);
}
#line 3238 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 139: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 912 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy203, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy323, 0, yymsp[-2].minor.yy206, yymsp[-5].minor.yy20);
}
#line 3249 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 143: /* idlist_opt ::= LP idlist RP */
#line 930 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy206 = yymsp[-1].minor.yy206;}
#line 3254 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 144: /* idlist ::= idlist COMMA nm */
#line 931 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy206 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy206,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy206 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3265 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 145: /* idlist ::= nm */
#line 938 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  /* yylhsminor.yy206-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy206 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy206 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3277 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy206 = yylhsminor.yy206;
        break;
      case 146: /* expr ::= LP expr RP */
#line 1041 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy66,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy66.pExpr = yymsp[-1].minor.yy66.pExpr;}
#line 3283 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 147: /* term ::= NULL */
      case 151: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==151);
      case 152: /* term ::= STRING */ yytestcase(yyruleno==152);
      case 153: /* term ::= FALSE */ yytestcase(yyruleno==153);
      case 154: /* term ::= TRUE */ yytestcase(yyruleno==154);
      case 155: /* term ::= UNKNOWN */ yytestcase(yyruleno==155);
#line 1042 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy66,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3293 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 148: /* expr ::= ID|INDEXED */
      case 149: /* expr ::= JOIN_KW */ yytestcase(yyruleno==149);
#line 1043 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy66,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3299 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 150: /* expr ::= nm DOT nm */
#line 1045 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy66,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy66.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3318 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 156: /* term ::= INTEGER */
#line 1066 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yylhsminor.yy66.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy66.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy66.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy66.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy66.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy66.pExpr ) yylhsminor.yy66.pExpr->flags |= EP_Leaf;
}
#line 3333 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy66 = yylhsminor.yy66;
        break;
      case 157: /* expr ::= VARIABLE */
#line 1077 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy66, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
             pParse->line_pos, "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy66.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy66, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy66.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy66.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy66, &t, &t);
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy66.pExpr = NULL;
  }
}
#line 3363 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy66 = yylhsminor.yy66;
        break;
      case 158: /* expr ::= expr COLLATE ID|INDEXED */
#line 1102 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy66.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy66.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy66.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3372 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 159: /* expr ::= CAST LP expr AS typedef RP */
#line 1107 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy66,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy66.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy66.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy66.pExpr->type = yymsp[-1].minor.yy302.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy66.pExpr, yymsp[-3].minor.yy66.pExpr, 0);
}
#line 3386 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 160: /* expr ::= TRIM LP trim_operands RP */
#line 1118 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yylhsminor.yy66.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy475, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy66, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3394 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-3].minor.yy66 = yylhsminor.yy66;
        break;
      case 161: /* trim_operands ::= trim_from_clause expr */
#line 1126 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yylhsminor.yy475 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy475, yymsp[0].minor.yy66.pExpr);
}
#line 3402 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-1].minor.yy475 = yylhsminor.yy475;
        break;
      case 162: /* trim_operands ::= expr */
#line 1130 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yylhsminor.yy475 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy66.pExpr);
}
#line 3410 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy475 = yylhsminor.yy475;
        break;
      case 163: /* trim_from_clause ::= expr FROM */
#line 1142 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yylhsminor.yy475 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy66.pExpr);
}
#line 3418 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-1].minor.yy475 = yylhsminor.yy475;
        break;
      case 164: /* trim_from_clause ::= trim_specification expr_optional FROM */
#line 1146 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy271]);
  yylhsminor.yy475 = sql_expr_list_append(pParse->db, NULL, p);
  if (yymsp[-1].minor.yy81 != NULL)
    yylhsminor.yy475 = sql_expr_list_append(pParse->db, yylhsminor.yy475, yymsp[-1].minor.yy81);
}
#line 3430 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-2].minor.yy475 = yylhsminor.yy475;
        break;
      case 165: /* expr_optional ::= */
#line 1157 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[1].minor.yy81 = NULL; }
#line 3436 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 166: /* expr_optional ::= expr */
#line 1158 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yylhsminor.yy81 = yymsp[0].minor.yy66.pExpr; }
#line 3441 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy81 = yylhsminor.yy81;
        break;
      case 167: /* trim_specification ::= LEADING */
#line 1162 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy271 = TRIM_LEADING; }
#line 3447 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 168: /* trim_specification ::= TRAILING */
#line 1163 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy271 = TRIM_TRAILING; }
#line 3452 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 169: /* trim_specification ::= BOTH */
#line 1164 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy271 = TRIM_BOTH; }
#line 3457 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 170: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 171: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==171);
#line 1166 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy294 && yymsp[-1].minor.yy294->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy294->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy66.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy294, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy66,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy20==SF_Distinct && yylhsminor.yy66.pExpr ){
    yylhsminor.yy66.pExpr->flags |= EP_Distinct;
  }
}
#line 3476 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-4].minor.yy66 = yylhsminor.yy66;
        break;
      case 172: /* expr ::= ID|INDEXED LP STAR RP */
#line 1201 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yylhsminor.yy66.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy66,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3485 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-3].minor.yy66 = yylhsminor.yy66;
        break;
      case 173: /* expr ::= LP nexprlist COMMA expr RP */
#line 1236 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy294, yymsp[-1].minor.yy66.pExpr);
  yylhsminor.yy66.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy66.pExpr ){
    yylhsminor.yy66.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy66, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3500 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-4].minor.yy66 = yylhsminor.yy66;
        break;
      case 174: /* expr ::= expr AND expr */
      case 175: /* expr ::= expr OR expr */ yytestcase(yyruleno==175);
      case 176: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==176);
      case 177: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==177);
      case 178: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==178);
      case 179: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==179);
      case 180: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==180);
      case 181: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==181);
#line 1247 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy66,&yymsp[0].minor.yy66);}
#line 3513 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 182: /* likeop ::= LIKE_KW|MATCH */
#line 1260 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3518 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 183: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1261 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3523 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 184: /* expr ::= expr likeop expr */
#line 1262 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy66.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy66.pExpr);
  yymsp[-2].minor.yy66.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy66);
  yymsp[-2].minor.yy66.zEnd = yymsp[0].minor.yy66.zEnd;
  if( yymsp[-2].minor.yy66.pExpr ) yymsp[-2].minor.yy66.pExpr->flags |= EP_InfixFunc;
}
#line 3538 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 185: /* expr ::= expr likeop expr ESCAPE expr */
#line 1273 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy66.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy66.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy66.pExpr);
  yymsp[-4].minor.yy66.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy66);
  yymsp[-4].minor.yy66.zEnd = yymsp[0].minor.yy66.zEnd;
  if( yymsp[-4].minor.yy66.pExpr ) yymsp[-4].minor.yy66.pExpr->flags |= EP_InfixFunc;
}
#line 3554 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 186: /* expr ::= expr IS NULL */
#line 1303 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy66,&yymsp[0].minor.yy0);}
#line 3559 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 187: /* expr ::= expr IS NOT NULL */
#line 1304 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy66,&yymsp[0].minor.yy0);}
#line 3564 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 188: /* expr ::= NOT expr */
      case 189: /* expr ::= BITNOT expr */ yytestcase(yyruleno==189);
#line 1326 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy66,pParse,yymsp[-1].major,&yymsp[0].minor.yy66,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3570 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 190: /* expr ::= MINUS expr */
#line 1330 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy66,pParse,TK_UMINUS,&yymsp[0].minor.yy66,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3575 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 191: /* expr ::= PLUS expr */
#line 1332 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy66,pParse,TK_UPLUS,&yymsp[0].minor.yy66,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3580 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 192: /* between_op ::= BETWEEN */
      case 195: /* in_op ::= IN */ yytestcase(yyruleno==195);
#line 1335 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = 0;}
#line 3586 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 194: /* expr ::= expr between_op expr AND expr */
#line 1337 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy66.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy66.pExpr);
  yymsp[-4].minor.yy66.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy66.pExpr, 0);
  if( yymsp[-4].minor.yy66.pExpr ){
    yymsp[-4].minor.yy66.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy20, &yymsp[-4].minor.yy66);
  yymsp[-4].minor.yy66.zEnd = yymsp[0].minor.yy66.zEnd;
}
#line 3602 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 197: /* expr ::= expr in_op LP exprlist RP */
#line 1352 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy294==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy66.pExpr, false);
    int tk = yymsp[-3].minor.yy20 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy66.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy66.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy66.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy294->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy294->a[0].pExpr;
    yymsp[-1].minor.yy294->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy294);
    yymsp[-4].minor.yy66.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy20 ? TK_NE : TK_EQ, yymsp[-4].minor.yy66.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy66.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy66.pExpr, 0);
    if( yymsp[-4].minor.yy66.pExpr ){
      yymsp[-4].minor.yy66.pExpr->x.pList = yymsp[-1].minor.yy294;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy66.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy294);
    }
    exprNot(pParse, yymsp[-3].minor.yy20, &yymsp[-4].minor.yy66);
  }
  yymsp[-4].minor.yy66.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3652 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 198: /* expr ::= LP select RP */
#line 1398 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy66,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy66.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy66.pExpr, yymsp[-1].minor.yy297);
}
#line 3661 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 199: /* expr ::= expr in_op LP select RP */
#line 1403 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy66.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy66.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy66.pExpr, yymsp[-1].minor.yy297);
  exprNot(pParse, yymsp[-3].minor.yy20, &yymsp[-4].minor.yy66);
  yymsp[-4].minor.yy66.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3671 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 200: /* expr ::= expr in_op nm paren_exprlist */
#line 1409 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy294 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy294);
  yymsp[-3].minor.yy66.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy66.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy66.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy20, &yymsp[-3].minor.yy66);
  yymsp[-3].minor.yy66.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3688 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 201: /* expr ::= EXISTS LP select RP */
#line 1422 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy66,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy66.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy297);
}
#line 3698 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 202: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1430 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy66,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy66.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy81, 0);
  if( yymsp[-4].minor.yy66.pExpr ){
    yymsp[-4].minor.yy66.pExpr->x.pList = yymsp[-1].minor.yy60 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy294,yymsp[-1].minor.yy60) : yymsp[-2].minor.yy294;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy66.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy294);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy60, false);
  }
}
#line 3713 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 203: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1443 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy294 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy294, yymsp[-2].minor.yy66.pExpr);
  yymsp[-4].minor.yy294 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy294, yymsp[0].minor.yy66.pExpr);
}
#line 3721 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 204: /* case_exprlist ::= WHEN expr THEN expr */
#line 1447 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy294 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy66.pExpr);
  yymsp[-3].minor.yy294 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy294, yymsp[0].minor.yy66.pExpr);
}
#line 3729 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 208: /* nexprlist ::= nexprlist COMMA expr */
#line 1464 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy294 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy294,yymsp[0].minor.yy66.pExpr);}
#line 3734 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 209: /* nexprlist ::= expr */
#line 1466 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy294 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy66.pExpr); /*A-overwrites-Y*/}
#line 3739 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 211: /* paren_exprlist ::= LP exprlist RP */
      case 216: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==216);
#line 1473 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy294 = yymsp[-1].minor.yy294;}
#line 3745 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 212: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1479 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy294, yymsp[-8].minor.yy20,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy20);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3760 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 213: /* uniqueflag ::= UNIQUE */
#line 1492 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = SQL_INDEX_TYPE_UNIQUE;}
#line 3765 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 214: /* uniqueflag ::= */
#line 1493 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy20 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3770 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 217: /* eidlist ::= eidlist COMMA nm */
#line 1528 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy294 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy294, &yymsp[0].minor.yy0);
}
#line 3777 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 218: /* eidlist ::= nm */
#line 1531 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[0].minor.yy294 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3784 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 219: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1538 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy323, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy20);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 3793 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 220: /* cmd ::= SET SESSION nm EQ term */
#line 1546 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
    sql_setting_set(pParse,&yymsp[-2].minor.yy0,yymsp[0].minor.yy66.pExpr);
}
#line 3800 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 221: /* cmd ::= PRAGMA nm */
#line 1552 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0);
}
#line 3807 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 222: /* cmd ::= PRAGMA nm LP nm RP */
#line 1555 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);
}
#line 3814 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 223: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1558 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0);
}
#line 3821 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 224: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1563 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy191, &all);
}
#line 3832 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 225: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1573 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy323, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy20, yymsp[-4].minor.yy330.a, yymsp[-4].minor.yy330.b, yymsp[0].minor.yy60,
                          yymsp[-7].minor.yy20);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3842 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 226: /* trigger_time ::= BEFORE */
#line 1581 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy20 = TK_BEFORE; }
#line 3847 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 227: /* trigger_time ::= AFTER */
#line 1582 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy20 = TK_AFTER;  }
#line 3852 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 228: /* trigger_time ::= INSTEAD OF */
#line 1583 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = TK_INSTEAD;}
#line 3857 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 229: /* trigger_time ::= */
#line 1584 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[1].minor.yy20 = TK_BEFORE; }
#line 3862 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 230: /* trigger_event ::= DELETE|INSERT */
      case 231: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==231);
#line 1588 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy330.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy330.b = 0;}
#line 3868 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 232: /* trigger_event ::= UPDATE OF idlist */
#line 1590 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[-2].minor.yy330.a = TK_UPDATE; yymsp[-2].minor.yy330.b = yymsp[0].minor.yy206;}
#line 3873 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 233: /* foreach_clause ::= */
#line 1592 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "FOR EACH STATEMENT triggers are not implemented, "
           "please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3883 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 234: /* when_clause ::= */
#line 1602 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[1].minor.yy60 = 0; }
#line 3888 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 235: /* when_clause ::= WHEN expr */
#line 1603 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy60 = yymsp[0].minor.yy66.pExpr; }
#line 3893 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 236: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1607 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy191!=0 );
  yymsp[-2].minor.yy191->pLast->pNext = yymsp[-1].minor.yy191;
  yymsp[-2].minor.yy191->pLast = yymsp[-1].minor.yy191;
}
#line 3902 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 237: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1612 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy191!=0 );
  yymsp[-1].minor.yy191->pLast = yymsp[-1].minor.yy191;
}
#line 3910 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 238: /* trnm ::= nm DOT nm */
#line 1623 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "qualified table names are not allowed on INSERT, "
           "UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3921 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 239: /* tridxby ::= INDEXED BY nm */
#line 1636 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the INDEXED BY clause is not allowed on UPDATE "\
           "or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3931 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 240: /* tridxby ::= NOT INDEXED */
#line 1642 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the NOT INDEXED BY clause is not allowed on "\
           "UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3941 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 241: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1655 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy191 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy294, yymsp[0].minor.yy60, yymsp[-5].minor.yy20);
     if (yymsp[-6].minor.yy191 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 3952 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 242: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1664 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  /*yylhsminor.yy191-overwrites-yymsp[-4].minor.yy20. */
  yylhsminor.yy191 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy206, yymsp[0].minor.yy297, yymsp[-4].minor.yy20);
  if (yylhsminor.yy191 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3964 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-4].minor.yy191 = yylhsminor.yy191;
        break;
      case 243: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1674 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy191 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy60);
  if (yymsp[-4].minor.yy191 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3976 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 244: /* trigger_cmd ::= select */
#line 1683 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  /* yylhsminor.yy191-overwrites-yymsp[0].minor.yy297. */
  yylhsminor.yy191 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy297);
  if (yylhsminor.yy191 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3988 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[0].minor.yy191 = yylhsminor.yy191;
        break;
      case 245: /* expr ::= RAISE LP IGNORE RP */
#line 1693 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy66,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy66.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy66.pExpr ){
    yymsp[-3].minor.yy66.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 4000 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 246: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1700 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy66,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy66.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy66.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy66.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy20;
}
#line 4013 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 247: /* raisetype ::= ROLLBACK */
#line 1711 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 4018 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 248: /* raisetype ::= ABORT */
#line 1712 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = ON_CONFLICT_ACTION_ABORT;}
#line 4023 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 249: /* raisetype ::= FAIL */
#line 1713 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[0].minor.yy20 = ON_CONFLICT_ACTION_FAIL;}
#line 4028 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 250: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1717 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy323, &t, yymsp[-1].minor.yy20);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 4038 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 251: /* alter_table_start ::= ALTER TABLE fullname */
#line 1734 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-2].minor.yy352 = yymsp[0].minor.yy323; }
#line 4043 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 252: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1737 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yylhsminor.yy334.table_name = yymsp[-3].minor.yy352;
  yylhsminor.yy334.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 4052 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
  yymsp[-3].minor.yy334 = yylhsminor.yy334;
        break;
      case 253: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1744 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy334.table_name, &yymsp[-11].minor.yy334.name, yymsp[-7].minor.yy294, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy294,
                     yymsp[-2].minor.yy20, yymsp[-1].minor.yy20, yymsp[0].minor.yy20);
  sql_create_foreign_key(pParse);
}
#line 4062 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 254: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1750 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy334.table_name, &yymsp[-4].minor.yy334.name, &yymsp[-1].minor.yy66);
    sql_create_check_contraint(pParse);
}
#line 4070 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 255: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1755 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy334.table_name, &yymsp[-4].minor.yy334.name, yymsp[-1].minor.yy294, yymsp[-3].minor.yy20,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4079 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 256: /* unique_spec ::= UNIQUE */
#line 1762 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy20 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4084 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 257: /* unique_spec ::= PRIMARY KEY */
#line 1763 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4089 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 258: /* cmd ::= alter_table_start RENAME TO nm */
#line 1765 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy352, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4098 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 259: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1771 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  drop_constraint_def_init(&pParse->drop_constraint_def, yymsp[-3].minor.yy323, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_constraint(pParse);
}
#line 4107 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 260: /* cmd ::= alter_table_start enable CHECK CONSTRAINT nm */
#line 1777 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
    enable_entity_def_init(&pParse->enable_entity_def, ENTITY_TYPE_CK, yymsp[-4].minor.yy352,
                           &yymsp[0].minor.yy0, yymsp[-3].minor.yy371);
    sql_alter_ck_constraint_enable(pParse);
}
#line 4116 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 261: /* with ::= */
#line 1789 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{yymsp[1].minor.yy203 = 0;}
#line 4121 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 262: /* with ::= WITH wqlist */
#line 1790 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-1].minor.yy203 = yymsp[0].minor.yy203; }
#line 4126 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 263: /* with ::= WITH RECURSIVE wqlist */
#line 1791 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[-2].minor.yy203 = yymsp[0].minor.yy203; }
#line 4131 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 264: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1793 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy203 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy294, yymsp[-1].minor.yy297); /*A-overwrites-X*/
}
#line 4138 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 265: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1796 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy203 = sqlWithAdd(pParse, yymsp[-7].minor.yy203, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy294, yymsp[-1].minor.yy297);
}
#line 4145 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 266: /* typedef ::= TEXT */
      case 267: /* typedef ::= STRING_KW */ yytestcase(yyruleno==267);
#line 1802 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy302.type = FIELD_TYPE_STRING; }
#line 4151 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 268: /* typedef ::= SCALAR */
#line 1804 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy302.type = FIELD_TYPE_SCALAR; }
#line 4156 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 269: /* typedef ::= BOOL */
      case 270: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==270);
#line 1806 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy302.type = FIELD_TYPE_BOOLEAN; }
#line 4162 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 271: /* typedef ::= VARBINARY */
#line 1808 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy302.type = FIELD_TYPE_VARBINARY; }
#line 4167 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 272: /* char_len ::= LP INTEGER RP */
#line 1820 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy20;
  (void) yymsp[-1].minor.yy0;
}
#line 4175 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 273: /* typedef ::= VARCHAR char_len */
#line 1826 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy302.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy20;
}
#line 4183 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 274: /* number_typedef ::= NUMBER */
#line 1833 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy302.type = FIELD_TYPE_NUMBER; }
#line 4188 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 275: /* number_typedef ::= DOUBLE */
#line 1834 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy302.type = FIELD_TYPE_DOUBLE; }
#line 4193 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 276: /* number_typedef ::= INT|INTEGER_KW */
#line 1835 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy302.type = FIELD_TYPE_INTEGER; }
#line 4198 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      case 277: /* number_typedef ::= UNSIGNED */
#line 1836 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"
{ yymsp[0].minor.yy302.type = FIELD_TYPE_UNSIGNED; }
#line 4203 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
        break;
      default:
      /* (278) input ::= ecmd */ yytestcase(yyruleno==278);
      /* (279) explain ::= */ yytestcase(yyruleno==279);
      /* (280) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=280);
      /* (281) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==281);
      /* (282) savepoint_opt ::= */ yytestcase(yyruleno==282);
      /* (283) cmd ::= create_table create_table_args with_opts create_table_end */ yytestcase(yyruleno==283);
      /* (284) create_table_args ::= LP columnlist RP */ yytestcase(yyruleno==284);
      /* (285) with_opts ::= WITH engine_opts */ yytestcase(yyruleno==285);
      /* (286) with_opts ::= */ yytestcase(yyruleno==286);
      /* (287) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==287);
      /* (288) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=288);
      /* (289) carglist ::= carglist ccons */ yytestcase(yyruleno==289);
      /* (290) carglist ::= */ yytestcase(yyruleno==290);
      /* (291) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=291);
      /* (292) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=292);
      /* (293) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=293);
      /* (294) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=294);
      /* (295) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=295);
      /* (296) oneselect ::= values */ yytestcase(yyruleno==296);
      /* (297) sclp ::= selcollist COMMA */ yytestcase(yyruleno==297);
      /* (298) as ::= ID|STRING */ yytestcase(yyruleno==298);
      /* (299) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==299);
      /* (300) join_nm ::= JOIN_KW */ yytestcase(yyruleno==300);
      /* (301) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=301);
      /* (302) type_func ::= CHAR */ yytestcase(yyruleno==302);
      /* (303) exprlist ::= nexprlist */ yytestcase(yyruleno==303);
      /* (304) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==304);
      /* (305) trnm ::= nm */ yytestcase(yyruleno==305);
      /* (306) tridxby ::= */ yytestcase(yyruleno==306);
      /* (307) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=307);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, TOKEN.n, TOKEN.z, TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, TOKEN.n,
             TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4304 "/build/usr/src/debug/tarantool-2.6.2.113/src/box/sql/parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
